@@ -24,7 +24,7 @@ from numbers import Number
 from typing import List, Dict, Optional, Tuple, Union, Set
 
 import numpy as np
-from pandas import DataFrame, Series, concat
+import pandas as pd
 
 from gs_quant.analytics.common import DATAGRID_HELP_MSG
 from gs_quant.analytics.common.helpers import resolve_entities, get_entity_rdate_key, get_entity_rdate_key_from_rdate, \
@@ -40,12 +40,12 @@ from gs_quant.analytics.datagrid.serializers import row_from_dict
 from gs_quant.analytics.datagrid.utils import DataGridSort, SortOrder, SortType, DataGridFilter, FilterOperation, \
     FilterCondition, get_utc_now
 from gs_quant.analytics.processors import CoordinateProcessor, EntityProcessor
+from gs_quant.common import Entitlements as Entitlements_
 from gs_quant.datetime.relative_date import RelativeDate
 from gs_quant.entities.entitlements import Entitlements
 from gs_quant.entities.entity import Entity
 from gs_quant.errors import MqValueError
 from gs_quant.session import GsSession, OAuth2Session
-from gs_quant.target.common import Entitlements as Entitlements_
 
 _logger = logging.getLogger(__name__)
 
@@ -55,7 +55,7 @@ DATAGRID_HEADERS: Dict[str, str] = {'Content-Type': 'application/json;charset=ut
 
 class DataGrid:
     """
-    DataGrid is a object for fetching Marquee data and applying processors (functions). DataGrids can be
+    DataGrid is an object for fetching Marquee data and applying processors (functions). DataGrids can be
     persisted via the DataGrid API and utilized on the Marquee Markets platform.
 
     :param name: Name of the DataGrid
@@ -66,6 +66,7 @@ class DataGrid:
     :param sorts: Optional list of DataGridSort. Use this if you want to sort your columns.
     :param filters: Optional list of DataGridFilter. Use this to filter column's data.
     :param multiColumnGroups: Optional list of MultiColumnGroup. Useful to group columns for heatmaps.
+
     **Usage**
 
     To create a DataGrid, we define two components, rows and columns:
@@ -401,7 +402,7 @@ class DataGrid:
                             query_info.data = queried_df[measure if isinstance(measure, str) else measure.value]
                     else:
                         for query_info in query_infos:
-                            query_info.data = Series(dtype=float)
+                            query_info.data = pd.Series(dtype=float)
 
         for query_info in self._data_queries:
             if isinstance(query_info, MeasureQueryInfo):
@@ -443,7 +444,7 @@ class DataGrid:
                 parameters.setdefault(dimension, set())
                 parameters[dimension].add(value)
 
-    def _post_process(self) -> DataFrame:
+    def _post_process(self) -> pd.DataFrame:
         columns = self.columns
         results = defaultdict(list)
         for row in self.results:
@@ -459,18 +460,17 @@ class DataGrid:
                     else:
                         results[column.name].append(column_data)
                 else:
-                    results[column.name].append(np.NaN)
+                    results[column.name].append(np.nan)
 
-        df = DataFrame.from_dict(results)
+        df = pd.DataFrame.from_dict(results)
         row_groups = list(df['rowGroup'].unique())
         sub_dfs = []
         for row_group in row_groups:
             sub_df = self.__handle_filters(df[df['rowGroup'] == row_group])
             sub_df = self.__handle_sorts(sub_df)
             sub_dfs.append(sub_df)
-        df = concat(sub_dfs)
-        df.set_index(['rowGroup', df.index], inplace=True)
-        df.rename_axis(index=['', ''], inplace=True)
+        df = pd.concat(sub_dfs)
+        df = df.set_index(['rowGroup', df.index]).rename_axis(index=['', ''])
         return df
 
     def __handle_sorts(self, df):
@@ -487,7 +487,7 @@ class DataGrid:
                 df = df.sort_values(by=sort.columnName, ascending=ascending, na_position='last')
         return df
 
-    def __handle_filters(self, df) -> DataFrame:
+    def __handle_filters(self, df) -> pd.DataFrame:
         """
         Handles filtering the dataframe
         :param df: incoming dataframe to be filtered
@@ -555,14 +555,14 @@ class DataGrid:
 
         return running_df
 
-    def to_frame(self) -> DataFrame:
+    def to_frame(self) -> pd.DataFrame:
         """
         Returns the results of the DataGrid data fetching and applied processors.
-        :return: DataFrame of results
+        :return: pd.DataFrame of results
         """
         if not self.is_initialized:
             _logger.info("Grid has not been initialized. Ensure to run DataGrid.initialize()")
-            return DataFrame()
+            return pd.DataFrame()
 
         return self._post_process()
 
