@@ -16,18 +16,19 @@ under the License.
 
 from typing import Optional, Union
 
-from pandas import Series
+import pandas as pd
 
 from gs_quant.analytics.core.processor import BaseProcessor, DataCoordinateOrProcessor, DataQueryInfo, \
     DateOrDatetimeOrRDate
 from gs_quant.analytics.core.processor_result import ProcessorResult
 from gs_quant.analytics.processors.special_processors import MeasureProcessor
+from gs_quant.common import Currency
+from gs_quant.data import DataFrequency
 from gs_quant.data.coordinate import DataCoordinate
 from gs_quant.data.query import DataQuery
 from gs_quant.entities.entity import Entity
 from gs_quant.markets.securities import Stock, Cross
-from gs_quant.target.common import Currency
-from gs_quant.timeseries import correlation, Window, SeriesType, DataMeasure, DataFrequency, DataContext, \
+from gs_quant.timeseries import correlation, Window, SeriesType, DataMeasure, DataContext, \
     fx_implied_correlation
 from gs_quant.timeseries import excess_returns_pure
 from gs_quant.timeseries.econometrics import get_ratio_pure, SharpeAssets, change, returns
@@ -282,7 +283,7 @@ class ReturnsProcessor(BaseProcessor):
                 data = a_data.data
                 if self.observations is None:
                     if len(data) > 1:
-                        self.value = ProcessorResult(True, Series([(data.iloc[-1] - data.iloc[0]) / data.iloc[-1]]))
+                        self.value = ProcessorResult(True, pd.Series([(data.iloc[-1] - data.iloc[0]) / data.iloc[0]]))
                     else:
                         self.value = ProcessorResult(True, 'Series has is less than 2.')
                 else:
