@@ -491,3 +491,44 @@ class StdMoveProcessor(BaseProcessor):
 
     def get_plot_expression(self):
         pass
+
+
+class CompoundGrowthRate(BaseProcessor):
+    def __init__(self,
+                 a: DataCoordinateOrProcessor,
+                 *,
+                 start: Optional[DateOrDatetimeOrRDate] = None,
+                 end: Optional[DateOrDatetimeOrRDate] = None,
+                 n: Optional[float] = None,
+                 **kwargs):
+        """ CompoundGrowthRate: indicates the growth rate over given time period n
+
+        :param a: DataCoordinate or BaseProcessor of series
+        :param start: start date or time used in the underlying data query
+        :param end: end date or time used in the underlying data query
+        :param n: Number of time
+        """
+        super().__init__(**kwargs)
+        self.children['a'] = a
+
+        self.start = start
+        self.end = end
+        self.n = n
+
+    def process(self):
+        a_data = self.children_data.get('a')
+        if isinstance(a_data, ProcessorResult):
+            if a_data.success:
+                data_series = a_data.data
+                self.value = ProcessorResult(
+                    True,
+                    pd.Series([(data_series.iloc[-1] / data_series.iloc[0]) ** (1 / self.n) - 1])
+                )
+            else:
+                self.value = ProcessorResult(False, "CompoundGrowthRate does not have 'a' series values yet")
+        else:
+            self.value = ProcessorResult(False, "CompoundGrowthRate does not have 'a' series yet")
+        return self.value
+
+    def get_plot_expression(self):
+        pass
