@@ -309,6 +309,32 @@ class DataGridComponent(Component):
         return dict_
 
 
+class DataScreenerComponent(Component):
+    def __init__(self,
+                 height: int,
+                 id_: str,
+                 *,
+                 width: int = None,
+                 tooltip: str = None):
+        """
+        Data Screener Component
+        :param height: height of the component
+        :param id_: unique identifier of the Data Screener
+        :param width: width of the component integers 1-12
+        :param tooltip: text to show in a tooltip on the Data Screener name
+        """
+        super().__init__(id_=id_, height=height, width=width)
+        self._type = 'screener'
+        self.tooltip = tooltip
+
+    def as_dict(self) -> Dict:
+        dict_ = super().as_dict()
+        if self.tooltip:
+            dict_['parameters']['tooltip'] = self.tooltip
+
+        return dict_
+
+
 class ArticleComponent(Component):
     def __init__(self,
                  height: int,
@@ -510,10 +536,13 @@ class PromoComponent(Component):
             dict_['parameters']['size'] = self.size.value
         if self.hide_border is not None:
             dict_['parameters']['hideBorder'] = self.size
+        if self.transparent is not None:
+            dict_['parameters']['transparent'] = self.transparent
 
         return dict_
 
-    def from_dict(cls, obj, scale: int = None):
+    @classmethod
+    def from_dict(cls, obj: Dict, scale: int = None):
         parameters = obj.get('parameters', {})
         size = parameters.get('size')
         size = PromoSize(size) if size else None
@@ -660,7 +689,7 @@ class RelatedLinksComponent(Component):
     def as_dict(self) -> Dict:
         dict_ = super().as_dict()
         dict_['parameters']['title'] = self.title
-        dict_['parameters']['title'] = [link.as_dict() for link in self.links]
+        dict_['parameters']['links'] = [link.as_dict() for link in self.links]
         return dict_
 
     @classmethod
@@ -682,5 +711,6 @@ TYPE_TO_COMPONENT = {
     'promo': PromoComponent,
     'relatedLinks': RelatedLinksComponent,
     'selector': SelectorComponent,
-    'separator': SeparatorComponent
+    'separator': SeparatorComponent,
+    'screener': DataScreenerComponent
 }
