@@ -14,9 +14,11 @@ specific language governing permissions and limitations
 under the License.
 """
 
+import datetime as dt
 from typing import Union
-from datetime import datetime
+
 import pandas as pd
+
 from gs_quant.data import DataCoordinate
 
 
@@ -31,7 +33,7 @@ class DataSeries:
 class DataEvent:
     """Represents a data update event"""
 
-    def __init__(self, time: datetime, value: Union[None, str, float], coordinate: DataCoordinate = None):
+    def __init__(self, time: dt.datetime, value: Union[None, str, float], coordinate: DataCoordinate = None):
         self.time = time
         self.value = value
         self.coordinate = coordinate
