@@ -22,6 +22,7 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Dict, List, Optional, Tuple, Union
 
+import deprecation
 import pandas as pd
 from pydash import get
 
@@ -35,20 +36,21 @@ from gs_quant.api.gs.indices import GsIndexApi
 from gs_quant.api.gs.portfolios import GsPortfolioApi
 from gs_quant.api.gs.reports import GsReportApi
 from gs_quant.api.gs.thematics import ThematicMeasure, GsThematicApi, Region
+from gs_quant.api.gs.scenarios import GsFactorScenarioApi
 from gs_quant.common import DateLimit, PositionType, Currency
 from gs_quant.data import DataCoordinate, DataFrequency, DataMeasure
 from gs_quant.data.coordinate import DataDimensions
 from gs_quant.entities.entitlements import Entitlements
 from gs_quant.errors import MqError, MqValueError
-from gs_quant.markets.factor import Factor
 from gs_quant.markets.indices_utils import BasketType, IndicesDatasets
 from gs_quant.markets.position_set import PositionSet
 from gs_quant.markets.report import PerformanceReport, FactorRiskReport, Report, ThematicReport, \
-    flatten_results_into_df, get_thematic_breakdown_as_df
-from gs_quant.models.risk_model import MacroRiskModel, ReturnFormat, FactorType
+    flatten_results_into_df, get_thematic_breakdown_as_df, ReturnFormat
+from gs_quant.markets.scenario import Scenario
 from gs_quant.session import GsSession
 from gs_quant.target.data import DataQuery
 from gs_quant.target.reports import ReportStatus, ReportType
+from gs_quant.entities.entity_utils import _explode_data
 
 _logger = logging.getLogger(__name__)
 
@@ -64,6 +66,7 @@ class EntityType(Enum):
     RISK_MODEL = 'risk_model'
     SUBDIVISION = 'subdivision'
     DATASET = 'dataset'
+    SCENARIO = 'scenario'
 
 
 @dataclass
@@ -76,6 +79,19 @@ class EntityIdentifier(Enum):
     pass
 
 
+class ScenarioCalculationType(Enum):
+    FACTOR_SCENARIO = "Factor Scenario"
+
+
+class ScenarioCalculationMeasure(Enum):
+    SUMMARY = "Summary"
+    ESTIMATED_FACTOR_PNL = "Factor Pnl"
+    ESTIMATED_PNL_BY_SECTOR = "By Sector Pnl Aggregations"
+    ESTIMATED_PNL_BY_REGION = "By Region Pnl Aggregations"
+    ESTIMATED_PNL_BY_DIRECTION = "By Direction Pnl Aggregations"
+    ESTIMATED_PNL_BY_ASSET = "By Asset Pnl"
+
+
 class Entity(metaclass=ABCMeta):
     """Base class for any first-class entity"""
     _entity_to_endpoint = {
@@ -407,15 +423,10 @@ class PositionedEntity(metaclass=ABCMeta):
             currency = GsPortfolioApi.get_portfolio(self.id).currency
             new_sets = []
             for pos_set in position_sets:
-                if pos_set.reference_notional is None:
-                    incorrect_set = any([pos.quantity is None or pos.weight is not None for pos in pos_set.positions])
-                    if incorrect_set:
-                        raise MqValueError('If you would like to upload position sets without notionals, '
-                                           'every position must have a quantity and cannot have a weight.')
-                    new_sets.append(pos_set)
-                else:
+                positions_are_missing_quantities = len([p for p in pos_set.positions if p.quantity is None]) > 0
+                if positions_are_missing_quantities:
                     pos_set.price(currency)
-                    new_sets.append(pos_set)
+                new_sets.append(pos_set)
             GsPortfolioApi.update_positions(portfolio_id=self.id, position_sets=[p.to_target() for p in new_sets],
                                             net_positions=net_positions)
             time.sleep(3)
@@ -426,15 +437,22 @@ class PositionedEntity(metaclass=ABCMeta):
                            start: dt.date = DateLimit.LOW_LIMIT.value,
                            end: dt.date = dt.date.today(),
                            fields: [str] = None,
-                           position_type: PositionType = PositionType.CLOSE,
-                           include_all_business_days: bool = False) -> List[Dict]:
+                           position_type: PositionType = PositionType.CLOSE) -> List[Dict]:
         if self.positioned_entity_type == EntityType.ASSET:
-            if include_all_business_days:
-                raise MqError('"include_all_business_days" cannot be set to true for assets')
             return GsIndexApi.get_positions_data(self.id, start, end, fields, position_type)
         if self.positioned_entity_type == EntityType.PORTFOLIO:
-            return GsPortfolioApi.get_positions_data(self.id, start, end, fields,
-                                                     position_type, include_all_business_days)
+            raise MqError('Please use the get_positions_data function on the portfolio performance report using the '
+                          'PerformanceReport class')
+        raise NotImplementedError
+
+    def get_last_positions_data(self,
+                                fields: [str] = None,
+                                position_type: PositionType = PositionType.CLOSE) -> List[Dict]:
+        if self.positioned_entity_type == EntityType.ASSET:
+            return GsIndexApi.get_last_positions_data(self.id, fields, position_type)
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            raise MqError('Please use the get_positions_data function on the portfolio performance report using the '
+                          'PerformanceReport class')
         raise NotImplementedError
 
     def get_position_dates(self) -> Tuple[dt.date, ...]:
@@ -444,9 +462,9 @@ class PositionedEntity(metaclass=ABCMeta):
             return GsAssetApi.get_position_dates(asset_id=self.id)
         raise NotImplementedError
 
-    def get_reports(self) -> List[Report]:
+    def get_reports(self, tags: Dict = None) -> List[Report]:
         if self.positioned_entity_type == EntityType.PORTFOLIO:
-            reports_as_target = GsPortfolioApi.get_reports(portfolio_id=self.id)
+            reports_as_target = GsPortfolioApi.get_reports(portfolio_id=self.id, tags=tags)
         elif self.positioned_entity_type == EntityType.ASSET:
             reports_as_target = GsAssetApi.get_reports(asset_id=self.id)
         else:
@@ -457,12 +475,14 @@ class PositionedEntity(metaclass=ABCMeta):
                 report_objects.append(PerformanceReport.from_target(report))
             elif report.type in [ReportType.Portfolio_Factor_Risk, ReportType.Asset_Factor_Risk]:
                 report_objects.append(FactorRiskReport.from_target(report))
+            elif report.type in [ReportType.Portfolio_Thematic_Analytics, ReportType.Asset_Thematic_Analytics]:
+                report_objects.append(ThematicReport.from_target(report))
             else:
                 report_objects.append(Report.from_target(report))
         return report_objects
 
-    def get_status_of_reports(self) -> pd.DataFrame:
-        reports = self.get_reports()
+    def get_status_of_reports(self, tags: Dict = None) -> pd.DataFrame:
+        reports = self.get_reports(tags)
         reports_dict = {
             'Name': [r.name for r in reports],
             'ID': [r.id for r in reports],
@@ -474,13 +494,15 @@ class PositionedEntity(metaclass=ABCMeta):
 
         return pd.DataFrame.from_dict(reports_dict)
 
-    def get_factor_risk_reports(self, fx_hedged: bool = None) -> List[FactorRiskReport]:
+    def get_factor_risk_reports(self, fx_hedged: bool = None, tags: Dict = None) -> List[FactorRiskReport]:
         if self.positioned_entity_type in [EntityType.PORTFOLIO, EntityType.ASSET]:
             position_source_type = self.positioned_entity_type.value.capitalize()
             reports = GsReportApi.get_reports(limit=100,
                                               position_source_type=position_source_type,
                                               position_source_id=self.id,
-                                              report_type=f'{position_source_type} Factor Risk')
+                                              report_type=f'{position_source_type} Factor Risk',
+                                              tags=tags,
+                                              scroll='1m')
             if fx_hedged:
                 reports = [report for report in reports if report.parameters.fx_hedged == fx_hedged]
             if len(reports) == 0:
@@ -491,9 +513,10 @@ class PositionedEntity(metaclass=ABCMeta):
     def get_factor_risk_report(self,
                                risk_model_id: str = None,
                                fx_hedged: bool = None,
-                               benchmark_id: str = None) -> FactorRiskReport:
+                               benchmark_id: str = None,
+                               tags: Dict = None) -> FactorRiskReport:
         position_source_type = self.positioned_entity_type.value.capitalize()
-        reports = self.get_factor_risk_reports(fx_hedged=fx_hedged)
+        reports = self.get_factor_risk_reports(fx_hedged=fx_hedged, tags=tags)
         if risk_model_id:
             reports = [report for report in reports if report.parameters.risk_model == risk_model_id]
         reports = [report for report in reports if report.parameters.benchmark == benchmark_id]
@@ -507,13 +530,15 @@ class PositionedEntity(metaclass=ABCMeta):
                           'function parameters.')
         return reports[0]
 
-    def get_thematic_report(self) -> ThematicReport:
+    def get_thematic_report(self, tags: Dict = None) -> ThematicReport:
         if self.positioned_entity_type in [EntityType.PORTFOLIO, EntityType.ASSET]:
             position_source_type = self.positioned_entity_type.value.capitalize()
             reports = GsReportApi.get_reports(limit=100,
                                               position_source_type=position_source_type,
                                               position_source_id=self.id,
-                                              report_type=f'{position_source_type} Thematic Analytics')
+                                              report_type=f'{position_source_type} Thematic Analytics',
+                                              tags=tags)
+            reports = [report for report in reports if report.parameters.tags == tags]
             if len(reports) == 0:
                 raise MqError(f'This {position_source_type} has no thematic analytics report.')
             return ThematicReport.from_target(reports[0])
@@ -817,6 +842,8 @@ class PositionedEntity(metaclass=ABCMeta):
         df = pd.DataFrame(df)
         return df.set_index('date')
 
+    @deprecation.deprecated(deprecated_in="0.9.110",
+                            details="Please use the same function using the ThematicReport class")
     def get_all_thematic_exposures(self,
                                    start_date: dt.date = None,
                                    end_date: dt.date = None,
@@ -830,6 +857,8 @@ class PositionedEntity(metaclass=ABCMeta):
                                               measures=[ThematicMeasure.ALL_THEMATIC_EXPOSURES])
         return flatten_results_into_df(results)
 
+    @deprecation.deprecated(deprecated_in="0.9.110",
+                            details="Please use the same function using the ThematicReport class")
     def get_top_five_thematic_exposures(self,
                                         start_date: dt.date = None,
                                         end_date: dt.date = None,
@@ -843,6 +872,8 @@ class PositionedEntity(metaclass=ABCMeta):
                                               measures=[ThematicMeasure.TOP_FIVE_THEMATIC_EXPOSURES])
         return flatten_results_into_df(results)
 
+    @deprecation.deprecated(deprecated_in="0.9.110",
+                            details="Please use the same function using the ThematicReport class")
     def get_bottom_five_thematic_exposures(self,
                                            start_date: dt.date = None,
                                            end_date: dt.date = None,
@@ -868,12 +899,144 @@ class PositionedEntity(metaclass=ABCMeta):
         """
         return get_thematic_breakdown_as_df(entity_id=self.id, date=date, basket_id=basket_id)
 
-    def get_macro_exposure(self,
-                           model: MacroRiskModel,
-                           date: dt.date,
-                           factor_type: FactorType,
-                           factor_categories: List[Factor] = [],
-                           get_factors_by_name: bool = True,
-                           return_format: ReturnFormat = ReturnFormat.DATA_FRAME
-                           ) -> Union[Dict, pd.DataFrame]:
-        raise NotImplementedError
+    def get_factor_scenario_analytics(self,
+                                      scenarios: List[Scenario],
+                                      date: dt.date,
+                                      measures: List[ScenarioCalculationMeasure],
+                                      risk_model: str = None,
+                                      return_format: ReturnFormat = ReturnFormat.DATA_FRAME) -> \
+            Union[Dict, Union[Dict, pd.DataFrame]]:
+
+        """Given a list of factor scenarios (historical simulation and/or custom shocks), return the estimated pnl
+         of the given positioned entity.
+         :param scenarios: List of factor-based scenarios
+         :param date: date to run scenarios.
+         :param measures: which metrics to return
+         :param risk_model: valid risk model ID
+         :param return_format: whether to return data formatted in a dataframe or as a dict
+
+          **Examples**
+
+            >>> from gs_quant.session import GsSession, Environment
+            >>> from gs_quant.markets.portfolio_manager import PortfolioManager, ReturnFormat
+            >>> from gs_quant.entities.entity import ScenarioCalculationMeasure, PositionedEntity
+            >>> from gs_quant.markets.scenario import Scenario
+
+          Get scenarios
+            >>> covid_19_omicron = Scenario.get_by_name("Covid 19 Omicron (v2)") # historical simulation
+            >>> custom_shock = Scenario.get_by_name("Shocking factor by x% (Propagated)") # custom shock
+            >>> risk_model = "RISK_MODEL_ID" # valid risk model ID
+
+          Instantiate your positionedEntity. Here, we are using one of its subclasses, PortfolioManager
+
+            >>> pm = PortfolioManager(portfolio_id="PORTFOLIO_ID")
+
+          Set the date you wish to run your scenario on
+
+           >>> date = dt.date(2023, 3, 7)
+
+          Run scenario and get estimated impact on your positioned entity
+
+          >>> scenario_analytics = pm.get_factor_scenario_analytics(
+          ...     scenarios=[covid_19_omicron, beta_propagated],
+          ...     date=date,
+          ...     measures=[ScenarioCalculationMeasure.SUMMARY,
+          ...               ScenarioCalculationMeasure.ESTIMATED_FACTOR_PNL,
+          ...               ScenarioCalculationMeasure.ESTIMATED_PNL_BY_SECTOR,
+          ...               ScenarioCalculationMeasure.ESTIMATED_PNL_BY_REGION,
+          ...               ScenarioCalculationMeasure.ESTIMATED_PNL_BY_DIRECTION,
+          ...               ScenarioCalculationMeasure.ESTIMATED_PNL_BY_ASSET],
+          ...     risk_model=risk_model)
+
+          By default, the result will be returned in a dict with keys as the measures/metrics requested and values as
+          the scenario calculation results formatted in a dataframe. To get the results in a dict, specify the return
+          format as JSON
+         """
+        risk_report = self.get_factor_risk_report(risk_model_id=risk_model)
+
+        id_to_scenario_map = {scenario.id: scenario for scenario in scenarios}
+        scenario_ids = list(id_to_scenario_map.keys())
+
+        calculation_request = {
+            "date": date,
+            "scenarioIds": scenario_ids,
+            "reportId": risk_report.id,
+            "measures": [m.value for m in measures],
+            "riskModel": risk_model,
+            "type": "Factor Scenario"
+        }
+
+        results = GsFactorScenarioApi.calculate_scenario(calculation_request)
+
+        scenarios = [id_to_scenario_map.get(sc_id) for sc_id in results.get('scenarios')]
+        calculation_results = results.get('results')
+
+        if return_format == ReturnFormat.JSON:
+            return dict(zip(scenarios, calculation_results))
+
+        result = {}
+
+        all_data = {}
+        [all_data.update({result_type: []}) for result_type in ['summary', 'factorPnl', 'bySectorAggregations',
+                                                                'byRegionAggregations', 'byDirectionAggregations',
+                                                                'byAsset']]
+
+        for i, calc_result in enumerate(calculation_results):
+            for result_type in ['summary', 'factorPnl', 'bySectorAggregations',
+                                'byRegionAggregations', 'byDirectionAggregations', 'byAsset']:
+                scenario_metadata_map = {"scenarioId": scenarios[i].id,
+                                         "scenarioName": scenarios[i].name,
+                                         "scenarioType": scenarios[i].type.value}
+                if result_type == 'summary':
+                    calc_result.get(result_type).update(scenario_metadata_map)
+                    all_data.get(result_type).append(calc_result.get(result_type))
+                else:
+                    [data_map.update(scenario_metadata_map) for data_map in calc_result.get(result_type, [])]
+                    [all_data.get(result_type).append(element) for element in calc_result.get(result_type, [])]
+
+        for result_type, result_label in {"summary": "summary",
+                                          "factorPnl": "factorCategories",
+                                          "bySectorAggregations": "sectors",
+                                          "byRegionAggregations": "countries",
+                                          "byDirectionAggregations": "direction",
+                                          "byAsset": "byAsset"}.items():
+            estimated_pnl_results_as_json = all_data.get(result_type)
+            if estimated_pnl_results_as_json:
+                estimated_pnl_df = pd.DataFrame.from_dict(estimated_pnl_results_as_json)
+                estimated_pnl_df = estimated_pnl_df.apply(
+                    _explode_data, axis=1, parent_label=result_label)
+                if isinstance(estimated_pnl_df, pd.Series):
+                    estimated_pnl_df = pd.concat(estimated_pnl_df.values, ignore_index=True)
+
+                estimated_pnl_df.columns = estimated_pnl_df.columns.map(lambda x: {
+                    "factorCategories": "Factor Category",
+                    "factors": "Factor",
+                    "sectors": "Sector",
+                    "countries": "Country",
+                    "industries": "Industry",
+                    "direction": "Direction",
+                    "scenarioId": "Scenario ID",
+                    "scenarioName": "Scenario Name",
+                    "scenarioType": "Scenario Type",
+                    "assetId": "Asset ID",
+                    "name": "Asset Name",
+                    "bbid": "BBID",
+                    "factorExposure": "Factor Exposure",
+                    "factorShock": "Factor Shock (%)",
+                    "exposure": "Exposure",
+                    "estimatedPnl": "Estimated Pnl",
+                    "estimatedPerformance": "Estimated Performance (%)",
+                    "stressedMarketValue": "Stressed Market Value"
+
+                }.get(x, x))
+                column_order = [col
+                                for col in ["Scenario ID", "Scenario Name", "Scenario Type", "Asset ID",
+                                            "BBID", "Asset Name", "Factor Category", "Factor", "Factor Exposure",
+                                            "Factor Shock (%)", "Sector", "Industry", "Country", "Direction",
+                                            "Exposure", "Estimated Pnl", "Estimated Performance (%)",
+                                            "Stressed Market Value"]
+                                if col in estimated_pnl_df.columns.tolist()]
+                estimated_pnl_df = estimated_pnl_df[column_order]
+                result[result_type] = estimated_pnl_df
+
+        return result
