@@ -21,12 +21,13 @@ from typing import Dict, Union
 import numpy as np
 import pandas as pd
 
-from gs_quant.api.gs.risk_models import GsFactorRiskModelApi, RiskModelDataMeasure, RiskModelDataAssetsRequest
+from gs_quant.api.gs.risk_models import GsFactorRiskModelApi, RiskModelDataMeasure, RiskModelDataAssetsRequest, \
+    IntradayFactorDataSource
 from gs_quant.data.core import DataContext
 from gs_quant.datetime import date, time
 from gs_quant.models.risk_model_utils import get_covariance_matrix_dataframe, build_factor_volatility_dataframe, \
     build_factor_data_map, build_pfp_data_dataframe
-from gs_quant.target.risk_models import RiskModelUniverseIdentifierRequest, IntradayFactorDataSource
+from gs_quant.target.risk_models import RiskModelUniverseIdentifierRequest
 
 
 class ReturnFormat(Enum):
