@@ -14,17 +14,17 @@ specific language governing permissions and limitations
 under the License.
 """
 import datetime as dt
-from gs_quant.base import Market, RiskKey
-from gs_quant.common import PricingLocation
-from gs_quant.datetime.date import prev_business_date
-from gs_quant.target.common import CloseMarket as _CloseMarket, LiveMarket as _LiveMarket, \
-    OverlayMarket as _OverlayMarket, RelativeMarket as _RelativeMarket, TimestampedMarket as _TimestampedMarket, \
-    RefMarket as _RefMarket
-from gs_quant.target.data import MarketDataCoordinate as __MarketDataCoordinate, \
-    MarketDataCoordinateValue as __MarketDataCoordinateValue
 import re
 from typing import Mapping, Optional, Tuple, Union
 
+from gs_quant.base import Market, RiskKey
+from gs_quant.common import CloseMarket as _CloseMarket, LiveMarket as _LiveMarket, \
+    OverlayMarket as _OverlayMarket, RelativeMarket as _RelativeMarket, TimestampedMarket as _TimestampedMarket, \
+    RefMarket as _RefMarket, PricingLocation
+from gs_quant.datetime.date import prev_business_date, location_to_tz_mapping
+from gs_quant.target.data import MarketDataCoordinate as __MarketDataCoordinate, \
+    MarketDataCoordinateValue as __MarketDataCoordinateValue
+
 
 def historical_risk_key(risk_key: RiskKey) -> RiskKey:
     market = LocationOnlyMarket(risk_key.market.location)
@@ -47,19 +47,27 @@ def market_location(location: Optional[PricingLocation] = None) -> PricingLocati
         return location
 
 
-def close_market_date(_location: Optional[Union[PricingLocation, str]] = None,
-                      date: Optional[dt.date] = None) -> dt.date:
+def close_market_date(location: Optional[Union[PricingLocation, str]] = None, date: Optional[dt.date] = None,
+                      roll_hr_and_min: Tuple[int, int] = (24, 0)) -> dt.date:
     """Determine market data date based on current location (to infer calendar)
     and current pricing date
 
-    :param _location: location (deprecated)
+    :param location: date location, used for the roll timezone
     :param date: pricing date
+    :param roll_hr_and_min: tuple of the hour and minute of the expected market data availability time
+    in the location timezone
     :return: close market date
     """
     from .core import PricingContext
     date = date or PricingContext.current.pricing_date
 
-    if date >= dt.date.today():
+    location_tz = location_to_tz_mapping[PricingLocation(location)]
+    now_time = dt.datetime.now().astimezone(location_tz).replace(tzinfo=None)
+    hr_offset = roll_hr_and_min[0]
+    min_offset = roll_hr_and_min[1]
+    roll_time = dt.datetime(date.year, date.month, date.day).replace(tzinfo=None) + \
+        dt.timedelta(hours=hr_offset, minutes=min_offset)
+    if now_time < roll_time:
         # Don't use the calendars argument here as external users do not (yet) have access to that dataset
         date = prev_business_date(date)
 
@@ -120,6 +128,7 @@ class CloseMarket(Market):
     and close_market_date
     """
     __date_cache = {}
+    roll_hr_and_min = (24, 0)  # tuple of today's expected hr/min of market data availability in the location tz
 
     def __init__(self,
                  date: Optional[dt.date] = None,
@@ -137,6 +146,15 @@ class CloseMarket(Market):
     def market(self):
         return _CloseMarket(date=self.date, location=self.location)
 
+    def to_dict(self):
+        return {'date': self.date, 'location': self.location, 'marketType': 'CloseMarket'}
+
+    def __hash__(self):
+        return hash((self.date, self.location))
+
+    def __eq__(self, other):
+        return isinstance(other, CloseMarket) and self.date == other.date and self.location == other.location
+
     @property
     def location(self) -> PricingLocation:
         if self.__location is not None and not self.check:
@@ -149,7 +167,7 @@ class CloseMarket(Market):
         if self.__date is not None and not self.check:
             return self.__date
         else:
-            return close_market_date(self.location, self.__date)
+            return close_market_date(self.location, self.__date, self.roll_hr_and_min)
 
 
 class TimestampedMarket(Market):
