@@ -1494,12 +1494,12 @@ class SecurityMaster:
         cls._source = source
 
     @classmethod
-    def _get_asset_query(cls,
-                         id_value: Union[str, List[str]],
-                         id_type: Union[AssetIdentifier, SecurityIdentifier],
-                         as_of: Union[dt.date, dt.datetime] = None,
-                         exchange_code: ExchangeCode = None,
-                         asset_type: AssetType = None) -> Tuple[Dict, dt.datetime]:
+    def get_asset_query(cls,
+                        id_value: Union[str, List[str]],
+                        id_type: Union[AssetIdentifier, SecurityIdentifier],
+                        as_of: Union[dt.date, dt.datetime] = None,
+                        exchange_code: ExchangeCode = None,
+                        asset_type: AssetType = None) -> Tuple[Dict, dt.datetime]:
         if not as_of:
             current = PricingContext.current
             if not current.is_entered:
@@ -1591,7 +1591,7 @@ class SecurityMaster:
             gs_asset = GsAssetApi.get_asset(id_value)
             return cls.__gs_asset_to_asset(gs_asset)
 
-        query, as_of = cls._get_asset_query(id_value, id_type, as_of, exchange_code, asset_type)
+        query, as_of = cls.get_asset_query(id_value, id_type, as_of, exchange_code, asset_type)
         if sort_by_rank:
             results = GsAssetApi.get_many_assets(as_of=as_of, return_type=dict, order_by=['>rank'], **query)
             return cls._get_asset_results(results, sort_by_rank)
@@ -1656,7 +1656,7 @@ class SecurityMaster:
             gs_asset = await GsAssetApi.get_asset_async(id_value)
             return cls.__gs_asset_to_asset(gs_asset)
 
-        query, as_of = cls._get_asset_query(id_value, id_type, as_of, exchange_code, asset_type)
+        query, as_of = cls.get_asset_query(id_value, id_type, as_of, exchange_code, asset_type)
         if sort_by_rank:
             results = await GsAssetApi.get_many_assets_async(as_of=as_of, return_type=dict, order_by=['>rank'], **query)
             return cls._get_asset_results(results, sort_by_rank)
@@ -1711,8 +1711,9 @@ class SecurityMaster:
         span = Tracer.active_span()
         tracer = Tracer('SecurityMaster.get_many_assets') if span and span.is_recording() else nullcontext()
         with tracer as scope:
-            scope.span.set_tag(f'request.ids.{id_type.value}', id_values)
-            query, as_of = cls._get_asset_query(id_values, id_type, as_of, exchange_code)
+            if scope and scope.span:
+                scope.span.set_tag(f'request.ids.{id_type.value}', len(id_values) if id_values else 0)
+            query, as_of = cls.get_asset_query(id_values, id_type, as_of, exchange_code)
             if sort_by_rank:
                 results = GsAssetApi.get_many_assets(as_of=as_of, order_by=['>rank'], limit=limit, **query)
             else:
@@ -1768,8 +1769,9 @@ class SecurityMaster:
         span = Tracer.active_span()
         tracer = Tracer('SecurityMaster.get_many_assets_async') if span and span.is_recording() else nullcontext()
         with tracer as scope:
-            scope.span.set_tag(f'request.ids.{id_type.value}', id_values)
-            query, as_of = cls._get_asset_query(id_values, id_type, as_of, exchange_code)
+            if scope and scope.span:
+                scope.span.set_tag(f'request.ids.{id_type.value}', len(id_values) if id_values else 0)
+            query, as_of = cls.get_asset_query(id_values, id_type, as_of, exchange_code)
             if sort_by_rank:
                 results = await GsAssetApi.get_many_assets_async(as_of=as_of, order_by=['>rank'], limit=limit, **query)
             else:
