@@ -403,7 +403,10 @@ class MqexsOtcSettlementType(EnumBase, Enum):
     Physical = 'Physical'
     CalMonth_Avg_No_Roll_Adjust = 'CalMonth Avg No Roll Adjust'
     Heren_Month_Ahead = 'Heren Month Ahead'
-    Heren_Day_Ahead = 'Heren Day Ahead'    
+    Heren_Day_Ahead = 'Heren Day Ahead'
+    Argus_Month_Ahead = 'Argus Month Ahead'
+    Argus_Day_Ahead = 'Argus Day Ahead'
+    Multi = 'Multi'    
 
 
 class MqexsPricingType(EnumBase, Enum):    
@@ -420,10 +423,12 @@ class MqexsPricingType(EnumBase, Enum):
     OptionChain = 'OptionChain'
     RFQ = 'RFQ'
     RFQSales = 'RFQSales'
+    GstRFQ = 'GstRFQ'
     Roll = 'Roll'
     RFQRollSales = 'RFQRollSales'
     Swap = 'Swap'
     RFQSwapSales = 'RFQSwapSales'
+    GstSwapRFQ = 'GstSwapRFQ'
     TradableStream = 'TradableStream'
     UnifiedRFQ = 'UnifiedRFQ'
     PCORFQ = 'PCORFQ'    
