@@ -13,17 +13,20 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
+import copy
 import datetime as dt
 
 import numpy as np
-from numpy import int64, float64, datetime64
 import pandas as pd
 import pytest
 
 from gs_quant.api.gs.data import GsDataApi
 from gs_quant.data import Dataset
 from gs_quant.session import GsSession, Environment
-from gs_quant.target.data import Format
+from gs_quant.target.data import Format, DataQuery
+from gs_quant.target.data import DataSetEntity
+from gs_quant.target.data import DataSetParameters
+from gs_quant.target.data import DataSetDimensions
 
 test_types = {
     'date': 'date',
@@ -147,16 +150,106 @@ test_data = [
     }
 ]
 
+tr_types = {
+    'time': 'date-time',
+    'assetId': 'string',
+    'askPrice': 'number',
+    'adjustedAskPrice': 'number',
+    'bidPrice': 'number',
+    'adjustedBidPrice': 'number',
+    'tradePrice': 'number',
+    'adjustedTradePrice': 'number',
+    'openPrice': 'number',
+    'adjustedOpenPrice': 'number',
+    'highPrice': 'number',
+    'adjustedLowPrice': 'number',
+    'lowPrice': 'number',
+    'adjustedHighPrice': 'number'
+}
+tr_data = [
+    {
+        'time': dt.datetime(2023, 5, 31, 14),
+        'assetId': 'MA4B66MW5E27U8P32SB',
+        'askPrice': 2529,
+        'adjustedAskPrice': 2529,
+        'bidPrice': 2442.55,
+        'adjustedBidPrice': 2442.55,
+        'tradePrice': 2510.03,
+        'adjustedTradePrice': 2510.03,
+        'openPrice': 2476.96,
+        'adjustedOpenPrice': 2476.96,
+        'highPrice': 2519.49,
+        'lowPrice': 2467.47,
+        'adjustedHighPrice': 2519.49,
+        'adjustedLowPrice': 2467.47
+    },
+    {
+        'time': dt.datetime(2023, 5, 31, 15),
+        'assetId': 'MA4B66MW5E27U8P32SB',
+        'askPrice': 2502.34,
+        'adjustedAskPrice': 2502.34,
+        'bidPrice': 2418.09,
+        'adjustedBidPrice': 2418.09,
+        'tradePrice': 2447.89,
+        'adjustedTradePrice': 2447.89,
+        'openPrice': 2491.92,
+        'adjustedOpenPrice': 2491.92,
+        'highPrice': 2493.14,
+        'lowPrice': 2443.96,
+        'adjustedHighPrice': 2493.14,
+        'adjustedLowPrice': 2443.96
+    },
+    {
+        'time': dt.datetime(2023, 5, 31, 16),
+        'assetId': 'MA4B66MW5E27U8P32SB'
+    },
+    {
+        'time': dt.datetime(2023, 5, 31, 17),
+        'assetId': 'MA4B66MW5E27U8P32SB',
+        'askPrice': 2566.52,
+        'adjustedAskPrice': 2566.52,
+        'bidPrice': 2487.8,
+        'adjustedBidPrice': 2487.8,
+        'tradePrice': 2531.94,
+        'adjustedTradePrice': 2531.94,
+        'openPrice': 2474.33,
+        'adjustedOpenPrice': 2474.33,
+        'highPrice': 2538.07,
+        'lowPrice': 2474.33,
+        'adjustedHighPrice': 2538.07,
+        'adjustedLowPrice': 2474.33
+    }
+]
+
 test_coverage_data = {'results': [{'gsid': 'gsid1'}]}
 
 
 def test_query_data(mocker):
-    mocker.patch("gs_quant.api.gs.data.GsDataApi.query_data", return_value=test_data)
+    mock = mocker.patch("gs_quant.api.gs.data.GsDataApi.query_data", return_value=test_data)
     mocker.patch("gs_quant.api.gs.data.GsDataApi.get_types", return_value=test_types)
     dataset = Dataset(Dataset.TR.TREOD)
     data = dataset.get_data(dt.date(2019, 1, 2), dt.date(2019, 1, 9), assetId='MA4B66MW5E27U8P32SB')
     assert data.equals(GsDataApi.construct_dataframe_with_types(str(Dataset.TR.TREOD), test_data))
 
+    assert mock.call_count == 1
+    query = mock.call_args[0][0]
+    assert type(query) is DataQuery
+    assert query.empty_intervals is None
+
+
+def test_query_data_intervals(mocker):
+    mock = mocker.patch("gs_quant.api.gs.data.GsDataApi.query_data", return_value=tr_data)
+    mocker.patch("gs_quant.api.gs.data.GsDataApi.get_types", return_value=tr_types)
+    dataset = Dataset(Dataset.TR.TREOD)
+    data = dataset.get_data(dt.datetime(2023, 5, 31, 13), dt.datetime(2023, 5, 31, 17), assetId='MA4B66MW5E27U8P32SB',
+                            intervals=4, empty_intervals=True)
+    assert data.equals(GsDataApi.construct_dataframe_with_types(str(Dataset.TR.TR), tr_data))
+
+    assert mock.call_count == 1
+    query = mock.call_args[0][0]
+    assert type(query) is DataQuery
+    assert query.empty_intervals is True
+
 
 def test_query_data_types(mocker):
     mocker.patch("gs_quant.api.gs.data.GsDataApi.query_data", return_value=test_data)
@@ -204,11 +297,34 @@ def test_get_coverage(mocker):
 def test_construct_dataframe_with_types(mocker):
     mocker.patch("gs_quant.api.gs.data.GsDataApi.get_types", return_value=test_types)
     df = GsDataApi.construct_dataframe_with_types(str(Dataset.TR.TREOD), [test_data[0]])
-    assert np.issubdtype(df.index.dtype, datetime64)
-    assert df['adjustedAskPrice'].dtype == int64
-    assert df['adjustedBidPrice'].dtype == float64
+    assert np.issubdtype(df.index.dtype, np.datetime64)
+    assert df['adjustedAskPrice'].dtype == np.int64
+    assert df['adjustedBidPrice'].dtype == np.float64
     assert df['assetId'].dtype == object  # https://pbpython.com/pandas_dtypes.html python str == dtype object
-    assert np.issubdtype(df['updateTime'].dtype, datetime64)
+    assert np.issubdtype(df['updateTime'].dtype, np.datetime64)
+
+
+def test_construct_dataframe_var_schema(mocker):
+    mocker.patch("gs_quant.api.gs.data.GsDataApi.get_types", return_value=test_types)
+    var_schema = copy.deepcopy(test_data)
+    for i in range(len(var_schema)):
+        if i % 2 == 1:
+            prev = var_schema[i - 1]
+            curr = var_schema[i]
+            curr['difference_tradePrice'] = curr['tradePrice'] - prev['tradePrice']
+
+    df = GsDataApi.construct_dataframe_with_types(str(Dataset.TR.TREOD), var_schema, True)
+    assert np.issubdtype(df['difference_tradePrice'].dtype, np.floating)
+
+
+def test_dataframe_with_mixed_date_type(mocker):
+    mocker.patch.object(GsDataApi, 'get_types', return_value={'updateTime': 'date-time'})
+
+    df = GsDataApi.construct_dataframe_with_types('BBG_PER_SECURITY',
+                                                  [{'updateTime': '2022-02-24T19:25:28Z'},
+                                                   {'updateTime': '2022-11-10T17:18:23.021494Z'}])
+
+    assert df.empty is False
 
 
 def test_data_series_format(mocker):
@@ -227,6 +343,7 @@ def test_data_series_format(mocker):
         'data': test_data
     }
     mocker.patch.object(GsSession.current, '_post', side_effect=lambda *args, **kwargs: mock_response)
+    mocker.patch.object(GsSession.current, '_get', return_value={"id": "TREOD"})
     mocker.patch.object(GsDataApi, 'symbol_dimensions', return_value=('assetId',))
     mocker.patch("gs_quant.api.gs.data.GsDataApi.get_types", return_value=test_types)
 
@@ -249,5 +366,58 @@ def test_data_series_format(mocker):
     assert args[0] == '/data/TREOD/query'
 
 
+def test_get_data_bulk(mocker):
+
+    df2 = pd.DataFrame()
+    test_df = {
+        'date': {pd.Timestamp('20230302'): dt.date(2023, 3, 2)},
+        'clusterRegion': {pd.Timestamp('20230302'): 'Asia Pacific'},
+        'clusterClass': {pd.Timestamp('20230302'): '13'},
+        'assetId': {pd.Timestamp('20230302'): 'MA4B66MW5E27U8P4ZFX'},
+        'clusterDescription': {pd.Timestamp('20230302'): 'Small Trd Count, Hard to Complete'},
+        'updateTime': {pd.Timestamp('20230302'): dt.datetime.strptime('2023-03-05T00:40:54.000Z',
+                                                                      '%Y-%m-%dT%H:%M:%S.%fZ')}
+    }
+
+    df = pd.DataFrame(test_df)
+    df = df.set_index('date')
+
+    coverage = pd.DataFrame({'clusterRegion': ['Asia Pacific']})
+    symbol_dimension = ('clusterRegion',)
+    dataset_definition = DataSetEntity()
+    dataset_definition.parameters = DataSetParameters()
+    dataset_definition.parameters.history_date = dt.datetime(2017, 1, 2)
+    dataset_definition.dimensions = DataSetDimensions()
+    dataset_definition.dimensions.time_field = 'date'
+
+    # mock GsSession
+    mocker.patch.object(GsSession.__class__, 'default_value',
+                        return_value=GsSession.get(Environment.QA, 'client_id', 'secret'))
+
+    # mock fetch_data function in utilities.py
+    mock = mocker.patch("gs_quant.data.utilities.Utilities.fetch_data", return_value=df)
+
+    # mock granular functions in get_dataset_parameter in utilities.py
+    mocker.patch("gs_quant.api.gs.data.GsDataApi.symbol_dimensions", return_value=symbol_dimension)
+    mocker.patch("gs_quant.api.gs.data.GsDataApi.get_definition", return_value=dataset_definition)
+
+    # mock get_dataset_coverage function in utilities.py
+    mocker.patch("gs_quant.data.dataset.Dataset.get_coverage", return_value=coverage)
+
+    def handler(data_frame):
+        nonlocal df2
+        df2 = data_frame.head(1)
+
+    dataset_id = "EQTRADECLUSTERS"
+    original_start = dt.datetime(2023, 3, 2, 0, 0, 0)
+    final_end = dt.datetime(2023, 3, 2, 0, 0, 0)
+    c = Dataset(dataset_id)
+    c.get_data_bulk(original_start=original_start, final_end=final_end, request_batch_size=4,
+                    identifier="clusterRegion", handler=handler)
+
+    assert mock.call_count == 1
+    assert df.equals(df2)
+
+
 if __name__ == "__main__":
     pytest.main(args=["test_dataset.py"])
