@@ -17,7 +17,7 @@ under the License.
 import datetime as dt
 from base64 import b64encode
 
-from gs_quant.target.common import Entitlements
+from gs_quant.common import Entitlements
 from gs_quant.target.content import GetManyContentsResponse, ContentResponse, Content
 
 
