@@ -13,24 +13,24 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
+import datetime as dt
 from typing import Dict
 from unittest import mock
 
-import datetime as dt
 import pytest
 
-from gs_quant.api.gs.assets import AssetClass, AssetType, GsAsset, GsAssetApi
+from gs_quant.api.gs.assets import GsAsset, GsAssetApi
 from gs_quant.api.gs.indices import GsIndexApi
 from gs_quant.api.gs.reports import GsReportApi
 from gs_quant.api.gs.users import GsUsersApi
+from gs_quant.common import AssetClass, AssetType, Entitlements as TargetEntitlements, \
+    PositionSet as TargetPositionSet, Position as TargetPosition, ReportParameters, XRef
 from gs_quant.entities.entitlements import User
 from gs_quant.errors import MqError
 from gs_quant.markets.baskets import Basket, ErrorMessage
 from gs_quant.markets.indices_utils import ReturnType
 from gs_quant.markets.position_set import Position, PositionSet
 from gs_quant.session import GsSession, Environment
-from gs_quant.target.common import Entitlements as TargetEntitlements, \
-    PositionSet as TargetPositionSet, Position as TargetPosition, ReportParameters, XRef
 from gs_quant.target.indices import CustomBasketsResponse, CustomBasketRiskParams
 from gs_quant.target.reports import Report, User as TargetUser
 
@@ -38,7 +38,12 @@ from gs_quant.target.reports import Report, User as TargetUser
 asset_1 = {'name': 'asset 1', 'id': 'id1', 'bbid': 'bbid1'}
 asset_2 = {'name': 'asset 2', 'id': 'id2', 'bbid': 'bbid2'}
 assets_data = [asset_1, asset_2]
-base_user = {'name': 'First Last', 'email': 'ex@email.com', 'company': 'Company A'}
+base_user = {'name': 'First Last',
+             'email': 'ex@email.com',
+             'city': 'City A',
+             'company': 'Company A',
+             'country': 'Country A',
+             'region': 'Region A'}
 cb_response = CustomBasketsResponse('done', 'R1234567890', 'MA1234567890')
 gs_asset = GsAsset(asset_class=AssetClass.Equity,
                    type_=AssetType.Custom_Basket,
@@ -217,7 +222,7 @@ def test_basket_edit_and_rebalance(mocker):
     basket = Basket.get(ticker)
     basket.description = 'New Basket Description'
     gs_asset.description = 'New Basket Description'
-    basket.allow_ca_restricted_assets = True
+    basket.initial_price = 2000000
 
     mock_response(mocker, GsIndexApi, 'edit', cb_response)
     mock_response(mocker, GsReportApi, 'get_report', report)
@@ -248,7 +253,7 @@ def test_basket_update_entitlements(mocker):
     mock_response(mocker, GsAssetApi, 'update_asset_entitlements', entitlements_response)
     response = basket.update()
     GsAssetApi.update_asset_entitlements.assert_called()
-    assert response == entitlements_response.as_dict()
+    assert response == entitlements_response
 
 
 def test_upload_position_history(mocker):
