@@ -13,9 +13,10 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-import datetime
+import copy
+import datetime as dt
+import math
 
-import pandas
 import pandas as pd
 import pytest
 from testfixtures import Replacer
@@ -24,13 +25,12 @@ from testfixtures.mock import Mock
 import gs_quant.timeseries.measures_reports as mr
 from gs_quant.api.gs.assets import GsTemporalXRef
 from gs_quant.api.gs.data import MarketDataResponseFrame
+from gs_quant.common import ReportParameters, XRef
 from gs_quant.data.core import DataContext
 from gs_quant.errors import MqValueError
-from gs_quant.markets.portfolio_manager import CustomAUMDataPoint
-from gs_quant.markets.report import PerformanceReport, ThematicReport
+from gs_quant.markets.report import PerformanceReport, ThematicReport, CustomAUMDataPoint
 from gs_quant.markets.securities import Stock
 from gs_quant.models.risk_model import FactorRiskModel as Factor_Risk_Model
-from gs_quant.target.common import ReportParameters, XRef
 from gs_quant.target.portfolios import RiskAumSource
 from gs_quant.target.reports import Report, PositionSourceType, ReportType
 from gs_quant.target.risk_models import RiskModel, RiskModelCoverage, RiskModelTerm, RiskModelUniverseIdentifier
@@ -53,18 +53,18 @@ asset_factor_risk_report = Report(position_source_id='position source id',
                                   parameters=ReportParameters(risk_model='risk_model_id'),
                                   status='new')
 
-ppa_report = Report(position_source_id='position source id',
-                    position_source_type=PositionSourceType.Portfolio,
-                    type_=ReportType.Portfolio_Performance_Analytics,
-                    id_='report_id',
-                    parameters=ReportParameters(risk_model='risk_model_id'),
-                    status='new')
+ppa_report = PerformanceReport(position_source_id='position source id',
+                               position_source_type=PositionSourceType.Portfolio,
+                               type_=ReportType.Portfolio_Performance_Analytics,
+                               id_='report_id',
+                               parameters=ReportParameters(risk_model='risk_model_id'),
+                               status='new')
 
 factor_data = [
     {
         'date': '2020-11-23',
         'reportId': 'report_id',
-        'factor': 'factor_id',
+        'factor': 'Factor Name',
         'factorCategory': 'CNT',
         'pnl': 11.23,
         'exposure': -11.23,
@@ -73,7 +73,7 @@ factor_data = [
     {
         'date': '2020-11-24',
         'reportId': 'report_id',
-        'factor': 'factor_id',
+        'factor': 'Factor Name',
         'factorCategory': 'CNT',
         'pnl': 11.24,
         'exposure': -11.24,
@@ -82,14 +82,106 @@ factor_data = [
     {
         'date': '2020-11-25',
         'reportId': 'report_id',
-        'factor': 'factor_id',
+        'factor': 'Factor Name',
         'factorCategory': 'CNT',
         'pnl': 11.25,
         'exposure': -11.25,
         'proportionOfRisk': 3
+    },
+    {
+        'date': '2020-11-23',
+        'reportId': 'report_id',
+        'factor': 'Total',
+        'factorCategory': 'CNT',
+        'pnl': 19.23,
+        'exposure': -11.23,
+        'proportionOfRisk': 1
+    },
+    {
+        'date': '2020-11-24',
+        'reportId': 'report_id',
+        'factor': 'Total',
+        'factorCategory': 'CNT',
+        'pnl': 14.24,
+        'exposure': -11.24,
+        'proportionOfRisk': 2
+    },
+    {
+        'date': '2020-11-25',
+        'reportId': 'report_id',
+        'factor': 'Total',
+        'factorCategory': 'CNT',
+        'pnl': 21.25,
+        'exposure': -11.25,
+        'proportionOfRisk': 3
     }
 ]
 
+
+factor_exposure_data = [
+    {
+        'date': '2024-03-14',
+        'reportId': 'report_id',
+        'factor': 'Factor_1',
+        'factorCategory': 'Style',
+        'pnl': 19.23,
+        'exposure': 100,
+        'proportionOfRisk': 1
+    },
+    {
+        'date': '2024-03-14',
+        'reportId': 'report_id',
+        'factor': 'Factor_2',
+        'factorCategory': 'Style',
+        'pnl': 14.24,
+        'exposure': 100,
+        'proportionOfRisk': 2
+    },
+    {
+        'date': '2024-03-14',
+        'reportId': 'report_id',
+        'factor': 'Factor_3',
+        'factorCategory': 'Style',
+        'pnl': 21.25,
+        'exposure': 100,
+        'proportionOfRisk': 3
+    }
+]
+
+
+factor_return_data = [
+    {
+        "date": "2024-03-13",
+        "factor": "Factor_1",
+        "return": 2
+    },
+    {
+        "date": "2024-03-13",
+        "factor": "Factor_2",
+        "return": 3
+    },
+    {
+        "date": "2024-03-13",
+        "factor": "Factor_3",
+        "return": 2
+    },
+    {
+        "date": "2024-03-14",
+        "factor": "Factor_1",
+        "return": 2
+    },
+    {
+        "date": "2024-03-14",
+        "factor": "Factor_2",
+        "return": 3
+    },
+    {
+        "date": "2024-03-14",
+        "factor": "Factor_3",
+        "return": 2
+    },
+]
+
 aggregate_factor_data = [
     {
         'date': '2020-11-23',
@@ -314,6 +406,18 @@ thematic_data = [
 ]
 
 
+def compute_geometric_aggregation_calculations(aum: dict, pnl: dict, dates: list):
+    daily_returns = [0]
+    for i in range(2, len(dates)):
+        daily_returns.append(pnl[dates[i]] / aum[dates[i - 1]])
+
+    expected_values = [daily_returns[0]]
+    for i in range(1, len(daily_returns)):
+        expected_values.append((1 + expected_values[i - 1]) * (1 + daily_returns[i]) - 1)
+
+    return [v * 100 for v in expected_values]
+
+
 def mock_risk_model():
     risk_model = RiskModel(coverage=RiskModelCoverage.Country, id_='model_id', name='Fake Risk Model',
                            term=RiskModelTerm.Long, universe_identifier=RiskModelUniverseIdentifier.gsid, vendor='GS',
@@ -367,7 +471,7 @@ def test_factor_exposure():
         'factorCategory': 'Factor Name'
     }]
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         actual = mr.factor_exposure('report_id', 'Factor Name')
         assert all(actual.values == [-11.23, -11.24, -11.25])
 
@@ -413,24 +517,28 @@ def test_factor_exposure_percent():
         'factorCategory': 'Factor Name'
     }]
 
+    # mock getting performance report
+    mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_performance_report', Mock())
+    mock.return_value = ppa_report
+
     # mock getting aum source
-    mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_aum_source', Mock())
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum_source', Mock())
     mock.return_value = RiskAumSource.Custom_AUM
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         # mock getting aum
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_custom_aum', Mock())
-        mock.return_value = [CustomAUMDataPoint(date=datetime.date(2020, 11, 23), aum=2),
-                             CustomAUMDataPoint(date=datetime.date(2020, 11, 24), aum=2),
-                             CustomAUMDataPoint(date=datetime.date(2020, 11, 25), aum=2)]
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_custom_aum', Mock())
+        mock.return_value = [CustomAUMDataPoint(date=dt.date(2020, 11, 23), aum=2),
+                             CustomAUMDataPoint(date=dt.date(2020, 11, 24), aum=2),
+                             CustomAUMDataPoint(date=dt.date(2020, 11, 25), aum=2)]
         actual = mr.factor_exposure('report_id', 'Factor Name', 'Percent')
         assert all(actual.values == [-11.23 * 50, -11.24 * 50, -11.25 * 50])
 
     with pytest.raises(MqValueError):
         # mock getting aum with missing data
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_custom_aum', Mock())
-        mock.return_value = [CustomAUMDataPoint(date=datetime.date(2020, 11, 23), aum=2),
-                             CustomAUMDataPoint(date=datetime.date(2020, 11, 25), aum=2)]
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_custom_aum', Mock())
+        mock.return_value = [CustomAUMDataPoint(date=dt.date(2020, 11, 23), aum=2),
+                             CustomAUMDataPoint(date=dt.date(2020, 11, 25), aum=2)]
         mr.factor_exposure('report_id', 'Factor Name', 'Percent')
 
     replace.restore()
@@ -446,10 +554,6 @@ def test_factor_pnl():
     mock = replace('gs_quant.api.gs.reports.GsReportApi.get_report', Mock())
     mock.return_value = factor_risk_report
 
-    # mock getting report factor data
-    mock = replace('gs_quant.api.gs.reports.GsReportApi.get_factor_risk_report_results', Mock())
-    mock.return_value = factor_data
-
     # mock getting risk model dates
     mock = replace('gs_quant.api.gs.risk_models.GsRiskModelApi.get_risk_model_dates', Mock())
     mock.return_value = ['2010-01-01']
@@ -473,10 +577,32 @@ def test_factor_pnl():
         'factorCategory': 'Factor Name'
     }]
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
+        # mock getting report factor data
+        mock = replace('gs_quant.api.gs.reports.GsReportApi.get_factor_risk_report_results', Mock())
+        mock.return_value = factor_data
+
         actual = mr.factor_pnl('report_id', 'Factor Name')
         assert all(actual.values == [11.23, 11.24, 11.25])
 
+    with DataContext(dt.date(2020, 11, 22), dt.date(2020, 11, 25)):
+        # mock getting report factor data with first day set to 0
+        factor_data_copy = copy.copy(factor_data)
+        factor_data_copy.insert(0, {
+            'date': '2020-11-22',
+            'reportId': 'report_id',
+            'factor': 'Factor Name',
+            'factorCategory': 'CNT',
+            'pnl': 0,
+            'exposure': -11.23,
+            'proportionOfRisk': 1
+        })
+        mock = replace('gs_quant.api.gs.reports.GsReportApi.get_factor_risk_report_results', Mock())
+        mock.return_value = factor_data_copy
+
+        actual = mr.factor_pnl('report_id', 'Factor Name')
+        assert all(actual.values == [0.0, 11.23, 11.24, 11.25])
+
     with pytest.raises(MqValueError):
         mr.factor_pnl('report_id', 'Wrong Factor Name')
     replace.restore()
@@ -485,6 +611,8 @@ def test_factor_pnl():
 def test_factor_pnl_percent():
     replace = Replacer()
 
+    aum = {'2020-11-22': 200, '2020-11-23': 400, '2020-11-24': 400, '2020-11-25': 400}
+
     # mock getting risk model entity()
     mock = replace('gs_quant.api.gs.risk_models.GsRiskModelApi.get_risk_model', Mock())
     mock.return_value = risk_model
@@ -519,9 +647,15 @@ def test_factor_pnl_percent():
         'factorCategory': 'Factor Name'
     }]
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum
+
+    # Each team uses pnl today/aum yesterday
+    expected_values = [0, 0, 2.8844318, 5.7471343]
+
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         # mock getting aum source
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_aum_source', Mock())
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_aum_source', Mock())
         mock.return_value = RiskAumSource.Long
 
         # mock getting performance report
@@ -530,13 +664,13 @@ def test_factor_pnl_percent():
 
         # mock getting aum
         mock = replace('gs_quant.markets.report.PerformanceReport.get_long_exposure', Mock())
-        mock.return_value = pandas.DataFrame.from_dict({'date': ['2020-11-25'], 'longExposure': [100]})
+        mock.return_value = pd.DataFrame.from_dict({'date': aum.keys(), 'longExposure': aum.values()})
         actual = mr.factor_pnl('report_id', 'Factor Name', 'Percent')
-        assert all(actual.values == [11.23, 11.24, 11.25])
+        assert all([a == pytest.approx(e) for a, e in zip(actual.values, expected_values)])
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         # mock getting aum source
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_aum_source', Mock())
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_aum_source', Mock())
         mock.return_value = RiskAumSource.Short
 
         # mock getting performance report
@@ -545,13 +679,13 @@ def test_factor_pnl_percent():
 
         # mock getting aum
         mock = replace('gs_quant.markets.report.PerformanceReport.get_short_exposure', Mock())
-        mock.return_value = pandas.DataFrame.from_dict({'date': ['2020-11-25'], 'shortExposure': [100]})
+        mock.return_value = pd.DataFrame.from_dict({'date': aum.keys(), 'shortExposure': aum.values()})
         actual = mr.factor_pnl('report_id', 'Factor Name', 'Percent')
-        assert all(actual.values == [11.23, 11.24, 11.25])
+        assert all([a == pytest.approx(e) for a, e in zip(actual.values, expected_values)])
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         # mock getting aum source
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_aum_source', Mock())
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_aum_source', Mock())
         mock.return_value = RiskAumSource.Gross
 
         # mock getting performance report
@@ -560,13 +694,13 @@ def test_factor_pnl_percent():
 
         # mock getting aum
         mock = replace('gs_quant.markets.report.PerformanceReport.get_gross_exposure', Mock())
-        mock.return_value = pandas.DataFrame.from_dict({'date': ['2020-11-25'], 'grossExposure': [400]})
+        mock.return_value = pd.DataFrame.from_dict({'date': aum.keys(), 'grossExposure': aum.values()})
         actual = mr.factor_pnl('report_id', 'Factor Name', 'Percent')
-        assert all(actual.values == [11.23 / 4, 11.24 / 4, 11.25 / 4])
+        assert all([a == pytest.approx(e) for a, e in zip(actual.values, expected_values)])
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         # mock getting aum source
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_aum_source', Mock())
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_aum_source', Mock())
         mock.return_value = RiskAumSource.Net
 
         # mock getting performance report
@@ -575,23 +709,9 @@ def test_factor_pnl_percent():
 
         # mock getting aum
         mock = replace('gs_quant.markets.report.PerformanceReport.get_net_exposure', Mock())
-        mock.return_value = pandas.DataFrame.from_dict({'date': ['2020-11-25'], 'netExposure': [200]})
+        mock.return_value = pd.DataFrame.from_dict({'date': aum.keys(), 'netExposure': aum.values()})
         actual = mr.factor_pnl('report_id', 'Factor Name', 'Percent')
-        assert all(actual.values == [11.23 / 2, 11.24 / 2, 11.25 / 2])
-
-    with pytest.raises(MqValueError):
-        # mock getting aum source
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_aum_source', Mock())
-        mock.return_value = RiskAumSource.Net
-
-        # mock getting performance report
-        mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_performance_report', Mock())
-        mock.return_value = PerformanceReport(id='ID')
-
-        # mock getting aum
-        mock = replace('gs_quant.markets.report.PerformanceReport.get_net_exposure', Mock())
-        mock.return_value = pandas.DataFrame.from_dict({'date': ['2020-11-24'], 'netExposure': [200]})
-        mr.factor_pnl('report_id', 'Factor Name', 'Percent')
+        assert all([a == pytest.approx(e) for a, e in zip(actual.values, expected_values)])
 
     replace.restore()
 
@@ -676,7 +796,7 @@ def test_factor_proportion_of_risk():
         'factorCategory': 'Factor Name'
     }]
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         actual = mr.factor_proportion_of_risk('report_id', 'Factor Name')
         assert all(actual.values == [1, 2, 3])
 
@@ -733,15 +853,15 @@ def test_aggregate_factor_support():
         'factorCategory': 'Factor Name'
     }]
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         actual = mr.factor_proportion_of_risk('report_id', 'Factor')
         assert all(actual.values == [1, 2, 3])
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         actual = mr.daily_risk('report_id', 'Factor')
         assert all(actual.values == [1, 2, 3])
 
-    with DataContext(datetime.date(2020, 11, 23), datetime.date(2020, 11, 25)):
+    with DataContext(dt.date(2020, 11, 23), dt.date(2020, 11, 25)):
         actual = mr.annual_risk('report_id', 'Factor')
         assert all(actual.values == [1, 2, 3])
 
@@ -779,7 +899,7 @@ def test_normalized_performance():
                                           parameters=ReportParameters(transaction_cost_model='FIXED'))
 
     for k, v in expected.items():
-        with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+        with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 3)):
             actual = mr.normalized_performance('MP1', k)
             assert all(actual.values == v.values)
     replace.restore()
@@ -813,7 +933,7 @@ def test_normalized_performance_short():
                                           parameters=ReportParameters(transaction_cost_model='FIXED'))
 
     for k, v in expected.items():
-        with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+        with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 3)):
             actual = mr.normalized_performance('MP1', k)
             assert all((actual.values - v.values) < 0.01)
     replace.restore()
@@ -841,7 +961,7 @@ def test_get_long_pnl():
                                           report_type='Portfolio Performance Analytics',
                                           parameters=ReportParameters(transaction_cost_model='FIXED'))
 
-    with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+    with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 3)):
         actual = mr.long_pnl('MP1')
         assert all(actual.values == expected.values)
     replace.restore()
@@ -869,7 +989,7 @@ def test_get_short_pnl():
                                           report_type='Portfolio Performance Analytics',
                                           parameters=ReportParameters(transaction_cost_model='FIXED'))
 
-    with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+    with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 3)):
         actual = mr.short_pnl('MP1')
         assert all(actual.values == expected.values)
     replace.restore()
@@ -896,7 +1016,7 @@ def test_get_short_pnl_empty():
                                           report_type='Portfolio Performance Analytics',
                                           parameters=ReportParameters(transaction_cost_model='FIXED'))
 
-    with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+    with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 3)):
         actual = mr.short_pnl('MP1')
         assert all(actual.values == expected.values)
     replace.restore()
@@ -923,7 +1043,7 @@ def test_get_long_pnl_empty():
                                           report_type='Portfolio Performance Analytics',
                                           parameters=ReportParameters(transaction_cost_model='FIXED'))
 
-    with DataContext(datetime.date(2020, 1, 1), datetime.date(2019, 1, 3)):
+    with DataContext(dt.date(2020, 1, 1), dt.date(2019, 1, 3)):
         actual = mr.long_pnl('MP1')
         assert all(actual.values == expected.values)
     replace.restore()
@@ -944,13 +1064,13 @@ def test_thematic_exposure():
     mock = Stock('MAA0NE9QX2ABETG6', 'Test Asset')
     xrefs = replace('gs_quant.timeseries.measures.GsAssetApi.get_asset_xrefs', Mock())
     xrefs.return_value = [
-        GsTemporalXRef(datetime.date(2019, 1, 1),
-                       datetime.date(2952, 12, 31),
+        GsTemporalXRef(dt.date(2019, 1, 1),
+                       dt.date(2952, 12, 31),
                        XRef(ticker='basket_ticker', ))
     ]
     replace('gs_quant.markets.securities.SecurityMaster.get_asset', Mock()).return_value = mock
 
-    with DataContext(datetime.date(2020, 7, 12), datetime.date(2020, 7, 15)):
+    with DataContext(dt.date(2020, 7, 12), dt.date(2020, 7, 15)):
         actual = mr.thematic_exposure('report_id', 'basket_ticker')
         assert all(actual.values == [2, 2, 2, 2])
 
@@ -972,18 +1092,164 @@ def test_thematic_beta():
     mock = Stock('MAA0NE9QX2ABETG6', 'Test Asset')
     xrefs = replace('gs_quant.timeseries.measures.GsAssetApi.get_asset_xrefs', Mock())
     xrefs.return_value = [
-        GsTemporalXRef(datetime.date(2019, 1, 1),
-                       datetime.date(2952, 12, 31),
+        GsTemporalXRef(dt.date(2019, 1, 1),
+                       dt.date(2952, 12, 31),
                        XRef(ticker='basket_ticker', ))
     ]
     replace('gs_quant.markets.securities.SecurityMaster.get_asset', Mock()).return_value = mock
 
-    with DataContext(datetime.date(2020, 7, 12), datetime.date(2020, 7, 15)):
+    with DataContext(dt.date(2020, 7, 12), dt.date(2020, 7, 15)):
         actual = mr.thematic_beta('report_id', 'basket_ticker')
         assert all(actual.values == [1, 1, 1, 1])
 
     replace.restore()
 
 
+def test_aum():
+    replace = Replacer()
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = {
+        '2022-07-01': 100,
+        '2022-07-02': 200
+    }
+
+    with DataContext(dt.date(2022, 7, 1), dt.date(2022, 7, 3)):
+        actual = mr.aum('RP1')
+        assert all(actual.values == [100, 200])
+
+    replace.restore()
+
+
+def test_pnl():
+    replace = Replacer()
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
+
+    # mock PerformanceReport.get_pnl()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
+    mock.return_value = pd.DataFrame.from_dict(
+        {'date': ['2022-07-01', '2022-07-02', '2022-07-03'], 'pnl': [200, 400, 600]})
+
+    with DataContext(dt.date(2022, 7, 1), dt.date(2022, 7, 3)):
+        actual = mr.pnl('RP1')
+        assert all(actual.values == [200, 400, 600])
+
+    replace.restore()
+
+
+def test_pnl_percent():
+    replace = Replacer()
+
+    # mock PerformanceReport.get()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get', Mock())
+    mock.return_value = PerformanceReport(report_id='RP1',
+                                          position_source_type='Portfolio',
+                                          position_source_id='MP1',
+                                          report_type='Portfolio Performance Analytics',
+                                          parameters=ReportParameters(transaction_cost_model='FIXED'))
+
+    pnl = {'2022-07-01': 200, '2022-07-02': 400, '2022-07-03': 600}
+    aum = {'2022-06-30': 2000, '2022-07-01': 3000, '2022-07-02': 3000, '2022-07-03': 4000}
+
+    # mock PerformanceReport.get_pnl()
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_pnl', Mock())
+    mock.return_value = pd.DataFrame.from_dict({'date': list(pnl.keys()), 'pnl': list(pnl.values())})
+
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum_source', Mock())
+    mock.return_value = RiskAumSource.Long
+
+    # mock getting performance report
+    mock = replace('gs_quant.markets.portfolio_manager.PortfolioManager.get_performance_report', Mock())
+    mock.return_value = PerformanceReport(id='ID')
+
+    mock = replace('gs_quant.markets.report.PerformanceReport.get_aum', Mock())
+    mock.return_value = aum
+
+    # Each team uses pnl today/aum yesterday
+    expected_values = compute_geometric_aggregation_calculations(aum, pnl, list(aum.keys()))
+
+    with DataContext(dt.date(2022, 7, 1), dt.date(2022, 7, 3)):
+        # mock getting aum
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_long_exposure', Mock())
+        mock.return_value = pd.DataFrame.from_dict({'date': aum.keys(), 'longExposure': aum.values()})
+
+        actual = mr.pnl('report_id', 'Percent')
+        assert all([a == pytest.approx(e) for a, e in zip(actual.values, expected_values)])
+
+    # with one day's aum missed to test forward filling logic
+    with DataContext(dt.date(2022, 7, 1), dt.date(2022, 7, 3)):
+        # mock getting aum with one day missed to test forward filling logic
+        aum = {'2022-06-30': 2000, '2022-07-01': 3000, '2022-07-03': 4000}
+        mock = replace('gs_quant.markets.report.PerformanceReport.get_long_exposure', Mock())
+        mock.return_value = pd.DataFrame.from_dict({'date': aum.keys(), 'longExposure': aum.values()})
+
+        actual = mr.pnl('report_id', 'Percent')
+        assert all([a == pytest.approx(e) for a, e in zip(actual.values, expected_values)])
+
+    replace.restore()
+
+
+def test_historical_simulation_estimated_pnl():
+    replace = Replacer()
+
+    # mock getting report
+    mock = replace('gs_quant.api.gs.reports.GsReportApi.get_report', Mock())
+    mock.return_value = factor_risk_report
+
+    # mock getting report factor data
+    mock = replace('gs_quant.api.gs.reports.GsReportApi.get_factor_risk_report_results', Mock())
+    mock.return_value = factor_exposure_data
+
+    # mock sending data request
+    mock = replace('gs_quant.api.gs.data.GsDataApi.execute_query', Mock())
+    mock.return_value = {"data": factor_return_data}
+
+    with DataContext(dt.date(2024, 3, 13), dt.date(2024, 3, 14)):
+        actual = mr.historical_simulation_estimated_pnl('report_id')
+        actual_values = actual.to_list()
+        assert all([math.isclose(x, actual_values[i]) for i, x in enumerate([7.0, 14.17])])
+
+    replace.restore()
+
+
+def test_historical_simulation_estimated_factor_attribution():
+    replace = Replacer()
+
+    # mock getting report
+    mock = replace('gs_quant.api.gs.reports.GsReportApi.get_report', Mock())
+    mock.return_value = factor_risk_report
+
+    # mock getting report factor data
+    mock = replace('gs_quant.api.gs.reports.GsReportApi.get_factor_risk_report_results', Mock())
+    mock.return_value = factor_exposure_data
+
+    # mock sending data request
+    mock = replace('gs_quant.api.gs.data.GsDataApi.execute_query', Mock())
+    mock.return_value = {"data": [data for data in factor_return_data if data['factor'] == 'Factor_1']}
+
+    with DataContext(dt.date(2024, 3, 13), dt.date(2024, 3, 14)):
+        actual = mr.historical_simulation_estimated_factor_attribution('report_id', "Factor_1")
+        actual_values = actual.to_list()
+        assert all([math.isclose(x, actual_values[i]) for i, x in enumerate([2.0, 4.04])])
+
+    replace.restore()
+
+
 if __name__ == '__main__':
     pytest.main(args=[__file__])
