@@ -16,12 +16,19 @@
 # description. Type annotations should be provided for parameters.
 
 
+import datetime as dt
 import math
+from enum import Enum
 from functools import reduce
+from numbers import Real
+from typing import Union, Optional, List
 
-from gs_quant.errors import MqTypeError
-from .datetime import *
-from .helper import plot_function
+import numpy as np
+import pandas as pd
+
+from .datetime import align
+from .helper import plot_function, Interpolate
+from ..errors import MqValueError, MqTypeError
 
 """
 Algebra library contains basic numerical and algebraic operations, including addition, division, multiplication,
@@ -468,7 +475,7 @@ def abs_(x: pd.Series) -> pd.Series:
 
     :math:`R_t = |X_t|`
 
-    Equivalent to :math:`R_t = \sqrt{X_t^2}`
+    Equivalent to :math:`R_t = sqrt{X_t^2}`
 
     **Examples**
 
@@ -611,6 +618,65 @@ def filter_(x: pd.Series, operator: Optional[FilterOperator] = None, value: Opti
     return x
 
 
+@plot_function
+def filter_dates(x: pd.Series, operator: Optional[FilterOperator] = None,
+                 dates: Union[List[dt.date], dt.date] = None) -> pd.Series:
+    """
+    Removes dates where comparison with the operator and dates combination results in true, defaults to removing
+    missing values from the series
+
+    :param x: timeseries
+    :param operator: FilterOperator describing logic for date removal, e.g 'less_than'
+    :param dates: date or list of dates to remove from the series
+    :return: timeseries with specified dates removed
+
+
+    **Usage**
+
+    Remove each date determined by operator and date from timeseries where that expression yields true
+
+    **Examples**
+
+    Remove today from time series
+
+    >>> prices = generate_series(100)
+    >>> filter_dates(prices, FilterOperator.EQUALS, date.today())
+
+    Remove dates before today from time series
+
+    >>> prices = generate_series(100)
+    >>> filter_dates(prices, FilterOperator.LESS, date.today())
+
+    """
+
+    if dates is None and operator is None:
+        x = x.dropna(axis=0, how='any')
+    elif dates is None:
+        raise MqValueError('No date is specified for the operator')
+    elif isinstance(dates, list) and operator not in [FilterOperator.EQUALS, FilterOperator.N_EQUALS]:
+        raise MqValueError('Operator does not work for list of dates')
+    else:
+        if operator == FilterOperator.EQUALS:
+            dates = dates if isinstance(dates, list) else [dates]
+            x = x.loc[~x.index.isin(dates)]
+        elif operator == FilterOperator.N_EQUALS:
+            dates = dates if isinstance(dates, list) else [dates]
+            x = x.loc[x.index.isin(dates)]
+        elif operator == FilterOperator.GREATER:
+            x = x.loc[x.index <= dates]
+        elif operator == FilterOperator.LESS:
+            x = x.loc[x.index >= dates]
+        elif operator == FilterOperator.L_EQUALS:
+            x = x.loc[x.index > dates]
+        elif operator == FilterOperator.G_EQUALS:
+            x = x.loc[x.index < dates]
+        else:
+            if not isinstance(operator, str):
+                operator = str(operator)
+            raise MqValueError('Unexpected operator: ' + operator)
+    return x
+
+
 def _sum_boolean_series(*series):
     if not 2 <= len(series) <= 100:
         raise MqValueError('expected between 2 and 100 arguments')
@@ -749,3 +815,18 @@ def weighted_sum(series: List[pd.Series], weights: list) -> pd.Series:
     series = [s.reindex(cal) for s in series]
     weights = [pd.Series(w, index=cal) for w in weights]
     return sum(series[i] * weights[i] for i in range(len(series))) / sum(weights)
+
+
+@plot_function
+def geometrically_aggregate(series: pd.Series) -> pd.Series:
+    """
+    Geometrically aggregate a series.
+
+    :param series: list of time series
+    :return: time series of geometrically aggregated results
+
+    **Usage**
+
+    Used to aggregate daily returns when expressed as weights
+    """
+    return series.add(1).cumprod() - 1
