@@ -13,24 +13,35 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
+import logging
+from typing import Optional, Union
 
-from functools import partial
+import numpy as np
+import pandas as pd
+import datetime as dt
+from functools import partial, reduce
+from numbers import Real
 
 from dateutil.relativedelta import relativedelta as rdelta
 from pydash import chunk
 
 from gs_quant.timeseries.econometrics import volatility, correlation
-from gs_quant.timeseries.helper import _create_enum, _tenor_to_month, _month_to_tenor
+
 from gs_quant.timeseries.measures_helper import VolReference, preprocess_implied_vol_strikes_eq
 from gs_quant import timeseries as ts
-from .statistics import *
+from .algebra import sqrt
+from .helper import _create_enum, _tenor_to_month, _month_to_tenor, requires_session, Returns, plot_function, \
+    plot_method, Window
 from ..api.gs.assets import GsAssetApi
-from ..api.gs.data import GsDataApi, MarketDataResponseFrame
+from ..api.gs.data import GsDataApi, MarketDataResponseFrame, QueryType
+from ..api.utils import ThreadPoolManager
+from ..data import DataContext
 from ..data.log import log_debug
+from ..errors import MqTypeError, MqValueError
 
 _logger = logging.getLogger(__name__)
 
-RebalFreq = _create_enum('RebalFreq', ['Daily', 'Monthly'])
+RebalFreq = _create_enum('RebalFreq', ['Daily', 'Weekly', 'Monthly'])
 ReturnType = _create_enum('ReturnType', ['excess_return'])
 
 
@@ -70,12 +81,17 @@ def backtest_basket(
     if rebal_freq == RebalFreq.DAILY:
         rebal_dates = cal
     else:
-        # Get hypothetical monthly rebalances
-        num_rebals = (cal[-1].year - cal[0].year) * 12 + cal[-1].month - cal[0].month
-        rebal_dates = [cal[0] + i * rdelta(months=1) for i in range(num_rebals + 1)]
-        # Convert these to actual calendar days
-        rebal_dates = [d for d in rebal_dates if d < max(cal)]
-        rebal_dates = [min(cal[cal >= date]) for date in rebal_dates]
+        if rebal_freq == RebalFreq.WEEKLY:
+            # Get hypothetical weekly rebalances
+            num_rebals = ((cal[-1] - cal[0]).days) // 7
+            rebal_dates = [cal[0] + i * rdelta(weeks=1) for i in range(num_rebals + 1)]
+        else:
+            # Get hypothetical monthly rebalances
+            num_rebals = (cal[-1].year - cal[0].year) * 12 + cal[-1].month - cal[0].month
+            rebal_dates = [cal[0] + i * rdelta(months=1) for i in range(num_rebals + 1)]
+
+        # Convert the hypothetical weekly/monthly rebalance dates to actual calendar days
+        rebal_dates = [min(cal[cal >= date]) for date in rebal_dates if date < max(cal)]
 
     # Create Units dataframe
     units = pd.DataFrame(index=cal, columns=series.columns)
@@ -140,7 +156,7 @@ def basket_series(
     :param series: list of time series of instrument prices
     :param weights: list of weights (defaults to evenly weight series)
     :param costs: list of execution costs in decimal (defaults to costs of 0)
-    :param rebal_freq: rebalancing frequency - Daily or Monthly (defaults to Daily)
+    :param rebal_freq: rebalancing frequency - Daily, Weekly or Monthly (defaults to Daily)
     :param return_type: return type of underlying instruments - only excess return is supported
     :return: time series of the resulting basket
 
@@ -236,7 +252,7 @@ class Basket:
 
         if self._returns is None or self._actual_weights is None:
             spot_df = self.get_spot_data(request_id=request_id)
-            spot_df.dropna(inplace=True)
+            spot_df = spot_df.dropna()
             spot_series = [spot_df[asset_id] for asset_id in spot_df]
             results = backtest_basket(spot_series, self.weights, rebal_freq=self.rebal_freq)
 
@@ -314,12 +330,12 @@ class Basket:
         actual_weights = self.get_actual_weights(request_id)
 
         # Add in today's data
-        today = datetime.date.today()
+        today = dt.date.today()
         if not real_time and DataContext.current.end_date >= today and \
                 (vol_data.empty or today not in vol_data.index.date):
             vol_data = ts.append_last_for_measure(vol_data, self.get_marquee_ids(), QueryType.IMPLIED_VOLATILITY, where,
                                                   source=source, request_id=request_id)
-            vol_data.index.rename('date', inplace=True)
+            vol_data.index = vol_data.index.rename('date')
 
         # Below transformations will throw errors if vol_data is empty
         if vol_data.empty:
@@ -330,7 +346,7 @@ class Basket:
         vols.index.name = None
 
         # Necessary when current values appended - set weights index to match vols index
-        actual_weights = actual_weights.reindex(vols.index).fillna(method='pad')
+        actual_weights = actual_weights.reindex(vols.index).ffill()
 
         return actual_weights.mul(vols).sum(axis=1, skipna=False)
 
@@ -358,7 +374,7 @@ class Basket:
         vols = pd.concat(vols, axis=1)
         vols.columns = list(spot_df)
         # Necessary when current values appended - set weights index to match vols index
-        actual_weights = actual_weights.reindex(vols.index).fillna(method='pad')
+        actual_weights = actual_weights.reindex(vols.index).ffill()
 
         return actual_weights.mul(vols, axis=1).sum(axis=1, skipna=False)
 
@@ -455,6 +471,6 @@ class Basket:
         actual_weights = self.get_actual_weights(request_id)
 
         # Necessary when current values appended - set weights index to match vols index
-        actual_weights = actual_weights.reindex(vols.index).fillna(method='pad')
+        actual_weights = actual_weights.reindex(pd.DatetimeIndex(vols.index)).ffill()
 
         return actual_weights.mul(vols).sum(axis=1, skipna=False)
