@@ -21,20 +21,16 @@ from typing import Optional, Union
 
 import pandas as pd
 
-from gs_quant.data import DataContext
-from gs_quant.datetime import GsCalendar
-from pandas import Series
-
-from gs_quant.target.common import Currency as CurrencyEnum, AssetClass, AssetType, PricingLocation
 from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.data import QueryType, GsDataApi
-
+from gs_quant.common import Currency as CurrencyEnum, AssetClass, AssetType, PricingLocation
+from gs_quant.data import DataContext
+from gs_quant.datetime import GsCalendar
 from gs_quant.errors import MqValueError
-from gs_quant.timeseries import ExtendedSeries, measures_rates as tm_rates, check_forward_looking
-from gs_quant.timeseries.measures import _asset_from_spec, _market_data_timed, _range_from_pricing_date, _get_custom_bd
-
 from gs_quant.markets.securities import AssetIdentifier, Asset
 from gs_quant.timeseries import ASSET_SPEC, plot_measure, MeasureDependency, GENERIC_DATE
+from gs_quant.timeseries import ExtendedSeries, measures_rates as tm_rates, check_forward_looking
+from gs_quant.timeseries.measures import _asset_from_spec, _market_data_timed, _range_from_pricing_date, _get_custom_bd
 from gs_quant.timeseries.measures_rates import _get_term_struct_date
 
 _logger = logging.getLogger(__name__)
@@ -276,7 +272,7 @@ def _get_inflation_swap_data(asset: Asset, swap_tenor: str, index_type: str = No
 def inflation_swap_rate(asset: Asset, swap_tenor: str, index_type: str = None,
                         forward_tenor: Optional[GENERIC_DATE] = None, clearing_house: tm_rates._ClearingHouse = None,
                         location: PricingLocation = None, *,
-                        source: str = None, real_time: bool = False) -> Series:
+                        source: str = None, real_time: bool = False) -> pd.Series:
     """
     GS end-of-day Zero Coupon Inflation Swap curves across major currencies.
 
@@ -307,7 +303,7 @@ def inflation_swap_rate(asset: Asset, swap_tenor: str, index_type: str = None,
 def inflation_swap_term(asset: Asset, index_type: str = None,
                         forward_tenor: Optional[GENERIC_DATE] = None, pricing_date: Optional[GENERIC_DATE] = None,
                         clearing_house: tm_rates._ClearingHouse = None, location: PricingLocation = None, *,
-                        source: str = None, real_time: bool = False, request_id: Optional[str] = None) -> Series:
+                        source: str = None, real_time: bool = False, request_id: Optional[str] = None) -> pd.Series:
     """
     Forward term structure of GS end-of-day inflation swaps.
 
@@ -353,7 +349,7 @@ def inflation_swap_term(asset: Asset, index_type: str = None,
         biz_day = _get_custom_bd(calendar)
         df['expirationDate'] = df['terminationTenor'].apply(_get_term_struct_date, args=(latest, biz_day))
         df = df.set_index('expirationDate')
-        df.sort_index(inplace=True)
+        df = df.sort_index()
         df = df.loc[DataContext.current.start_date: DataContext.current.end_date]
         series = ExtendedSeries(dtype=float) if df.empty else ExtendedSeries(df['swapRate'])
         series.dataset_ids = getattr(df, 'dataset_ids', ())
