@@ -20,13 +20,12 @@ from enum import Enum
 from typing import Optional, Union, Dict
 
 import pandas as pd
-from pandas import Series
 
 from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.data import QueryType, GsDataApi
 from gs_quant.errors import MqValueError
 from gs_quant.markets.securities import AssetIdentifier, Asset, SecurityMaster
-from gs_quant.target.common import Currency as CurrencyEnum, AssetClass, AssetType, PricingLocation
+from gs_quant.common import Currency as CurrencyEnum, AssetClass, AssetType, PricingLocation
 from gs_quant.timeseries import ASSET_SPEC, plot_measure, MeasureDependency, GENERIC_DATE
 from gs_quant.timeseries.measures import _asset_from_spec, _market_data_timed, ExtendedSeries
 from gs_quant.timeseries import measures_rates as tm_rates
@@ -39,6 +38,7 @@ class CrossCurrencyRateOptionType(Enum):
     OIS = 'OIS'
     EUROSTR = 'EUROSTR'
     SOFR = 'SOFR'
+    SOFRVLIBOR = 'SOFRVLIBOR'
     TestRateOption = 'TestRateOption'
 
 
@@ -68,6 +68,54 @@ class TdapiCrossCurrencyRatesDefaultsProvider:
 
 CROSSCURRENCY_RATES_DEFAULTS = {
     "CURRENCIES": {
+        "AUD": [
+            {"BenchmarkType": "LIBOR",
+             "rateOption": "AUD-BBR-BBSW",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["TKO"]},
+            {"BenchmarkType": "SOFR",
+             "rateOption": "AUD-AONIA-OIS-COMPOUND",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["TKO"]},
+            {"BenchmarkType": "SOFRVLIBOR",
+             "rateOption": "AUD-BBR-BBSW",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["TKO"]},
+        ],
+        "CAD": [
+            {"BenchmarkType": "LIBOR",
+             "rateOption": "CAD-BA-CDOR",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["NYC"]},
+            {"BenchmarkType": "SOFR",
+             "rateOption": "CAD-BA-CDOR",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["NYC"]},
+        ],
+        "CHF": [
+            {"BenchmarkType": "LIBOR",
+             "rateOption": "CHF-LIBOR-BBA",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["LDN"]},
+            {"BenchmarkType": "SOFR",
+             "rateOption": "CHF-SARON-OIS-COMPOUND",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["LDN"]},
+            {"BenchmarkType": "SOFRVLIBOR",
+             "rateOption": "CHF-LIBOR-BBA",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["LDN"]},
+        ],
+        "DKK": [
+            {"BenchmarkType": "LIBOR",
+             "rateOption": "DKK-CIBOR2-DKNA13",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["LDN"]},
+            {"BenchmarkType": "SOFR",
+             "rateOption": "DKK-CIBOR2-DKNA13",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["LDN"]},
+        ],
         "EUR": [
             {"BenchmarkType": "LIBOR",
              "rateOption": "EUR-EURIBOR-TELERATE",
@@ -82,20 +130,6 @@ CROSSCURRENCY_RATES_DEFAULTS = {
              "designatedMaturity": "3m",
              "pricingLocation": ["LDN"]}
         ],
-        "USD": [
-            {"BenchmarkType": "LIBOR",
-             "rateOption": "USD-LIBOR-BBA",
-             "designatedMaturity": "3m",
-             "pricingLocation": ["NYC"]},
-            {"BenchmarkType": "OIS",
-             "rateOption": "USD-FEDERAL FUNDS-H.15-OIS-COMP",
-             "designatedMaturity": "3m",
-             "pricingLocation": ["NYC"]},
-            {"BenchmarkType": "SOFR",
-             "rateOption": "USD-SOFR-COMPOUND",
-             "designatedMaturity": "3m",
-             "pricingLocation": ["NYC"]}
-        ],
         "GBP": [
             {"BenchmarkType": "LIBOR",
              "rateOption": "GBP-LIBOR-BBA",
@@ -124,47 +158,63 @@ CROSSCURRENCY_RATES_DEFAULTS = {
              "designatedMaturity": "3m",
              "pricingLocation": ["TKO"]}
         ],
-        "CHF": [
-            {"BenchmarkType": "LIBOR",
-             "rateOption": "CHF-LIBOR-BBA",
-             "designatedMaturity": "3m",
-             "pricingLocation": ["LDN"]},
-        ],
-        "DKK": [
-            {"BenchmarkType": "LIBOR",
-             "rateOption": "DKK-CIBOR2-DKNA13",
-             "designatedMaturity": "3m",
-             "pricingLocation": ["LDN"]},
-        ],
-        "SEK": [
-            {"BenchmarkType": "LIBOR",
-             "rateOption": "SEK-STIBOR-SIDE",
-             "designatedMaturity": "3m",
-             "pricingLocation": ["LDN"]},
-        ],
         "NOK": [
             {"BenchmarkType": "LIBOR",
              "rateOption": "NOK-NIBOR-BBA",
              "designatedMaturity": "3m",
              "pricingLocation": ["LDN"]},
-        ],
-        "AUD": [
-            {"BenchmarkType": "LIBOR",
-             "rateOption": "AUD-BBR-BBSW",
+            {"BenchmarkType": "SOFR",
+             "rateOption": "NOK-NIBOR-BBA",
              "designatedMaturity": "3m",
-             "pricingLocation": ["TKO"]},
+             "pricingLocation": ["LDN"]},
         ],
         "NZD": [
             {"BenchmarkType": "LIBOR",
              "rateOption": "NZD-BBR-FRA",
              "designatedMaturity": "3m",
              "pricingLocation": ["TKO"]},
+            {"BenchmarkType": "SOFR",
+             "rateOption": "NZD-NZIONA-OIS-COMPOUND",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["TKO"]},
+            {"BenchmarkType": "SOFRVLIBOR",
+             "rateOption": "NZD-BBR-FRA",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["TKO"]},
         ],
-        "CAD": [
+        "SEK": [
             {"BenchmarkType": "LIBOR",
-             "rateOption": "CAD-BA-CDOR",
+             "rateOption": "SEK-STIBOR-SIDE",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["LDN"]},
+            {"BenchmarkType": "SOFR",
+             "rateOption": "SEK-STIBOR-SIDE",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["LDN"]},
+        ],
+        "SGD": [
+            {"BenchmarkType": "SOFR",
+             "rateOption": "SGD-SORA-COMPOUND",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["TKO"]},
+        ],
+        "USD": [
+            {"BenchmarkType": "LIBOR",
+             "rateOption": "USD-LIBOR-BBA",
              "designatedMaturity": "3m",
              "pricingLocation": ["NYC"]},
+            {"BenchmarkType": "OIS",
+             "rateOption": "USD-FEDERAL FUNDS-H.15-OIS-COMP",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["NYC"]},
+            {"BenchmarkType": "SOFR",
+             "rateOption": "USD-SOFR-COMPOUND",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["NYC"]},
+            {"BenchmarkType": "SOFRVLIBOR",
+             "rateOption": "USD-SOFR-COMPOUND",
+             "designatedMaturity": "3m",
+             "pricingLocation": ["NYC"]}
         ],
     },
     "COMMON": {
@@ -177,20 +227,29 @@ CROSSCURRENCY_RATES_DEFAULTS = {
 crossCurrencyRates_defaults_provider = TdapiCrossCurrencyRatesDefaultsProvider(CROSSCURRENCY_RATES_DEFAULTS)
 
 CURRENCY_TO_XCCY_SWAP_RATE_BENCHMARK = {
-    'CHF': OrderedDict([('LIBOR', 'CHF-LIBOR-BBA'), ('OIS', 'CHF-SARON-OIS-COMPOUND')]),
+    'AUD': OrderedDict(
+        [('LIBOR', 'AUD-BBR-BBSW'), ('SOFR', 'AUD-AONIA-OIS-COMPOUND'), ('SOFRVLIBOR', 'AUD-BBR-BBSW')]),
+    'CAD': OrderedDict(
+        [('LIBOR', 'CAD-BA-CDOR'), ('SOFR', 'CAD-BA-CDOR')]),
+    'CHF': OrderedDict([('LIBOR', 'CHF-LIBOR-BBA'), ('OIS', 'CHF-SARON-OIS-COMPOUND'),
+                        ('SOFR', 'CHF-SARON-OIS-COMPOUND'), ('SOFRVLIBOR', 'CHF-LIBOR-BBA')]),
+    'DKK': OrderedDict([('LIBOR', 'DKK-CIBOR2-DKNA13'), ('SOFR', 'DKK-CIBOR2-DKNA13')]),
     'EUR': OrderedDict([('LIBOR', 'EUR-EURIBOR-TELERATE'), ('OIS', 'EUR-EONIA-OIS-COMPOUND'),
                         ('SOFR', 'EUR-EUROSTR-COMPOUND')]),
     'GBP': OrderedDict([('LIBOR', 'GBP-LIBOR-BBA'), ('OIS', 'GBP-SONIA-COMPOUND'), ('SOFR', 'GBP-SONIA-COMPOUND')]),
     'JPY': OrderedDict([('LIBOR', 'JPY-LIBOR-BBA'), ('OIS', 'JPY-TONA-OIS-COMPOUND'),
                         ('SOFR', 'JPY-TONA-OIS-COMPOUND')]),
+    'NOK': OrderedDict(
+        [('LIBOR', 'NOK-NIBOR-BBA'), ('SOFR', 'NOK-NIBOR-BBA')]),
+    'NZD': OrderedDict(
+        [('LIBOR', 'NZD-BBR-FRA'), ('SOFR', 'NZD-NZIONA-OIS-COMPOUND'), ('SOFRVLIBOR', 'NZD-BBR-FRA')]),
+    'SEK': OrderedDict(
+        [('LIBOR', 'SEK-STIBOR-SIDE'), ('SOFR', 'SEK-STIBOR-SIDE')]),
+    'SGD': OrderedDict(
+        [('SOFR', 'SGD-SORA-COMPOUND')]),
     'USD': OrderedDict(
-        [('LIBOR', 'USD-LIBOR-BBA'), ('OIS', 'USD-FEDERAL FUNDS-H.15-OIS-COMP'), ('SOFR', 'USD-SOFR-COMPOUND')]),
-    'SEK': {'LIBOR': 'SEK-STIBOR-SIDE'},
-    'NOK': {'LIBOR': 'NOK-NIBOR-BBA'},
-    'DKK': {'LIBOR': 'DKK-CIBOR2-DKNA13'},
-    'AUD': {'LIBOR': 'AUD-BBR-BBSW'},
-    'CAD': {'LIBOR': 'CAD-BA-CDOR'},
-    'NZD': {'LIBOR': 'NZD-BBR-FRA'},
+        [('LIBOR', 'USD-LIBOR-BBA'), ('OIS', 'USD-FEDERAL FUNDS-H.15-OIS-COMP'), ('SOFR', 'USD-SOFR-COMPOUND'),
+         ('SOFRVLIBOR', 'USD-SOFR-COMPOUND')]),
 }
 
 CURRENCY_TO_DUMMY_CROSSCURRENCY_SWAP_BBID = {
@@ -204,6 +263,7 @@ CURRENCY_TO_DUMMY_CROSSCURRENCY_SWAP_BBID = {
     'AUD': 'MAHN46BVXFAZ354E',
     'NZD': 'MAW1MNKPQWYJPX3A',
     'CAD': 'MAPRDGWMZSQJ8CZ0',
+    'SGD': 'MA7B3JT80Q617KGQ',
 }
 
 
@@ -387,7 +447,7 @@ def crosscurrency_swap_rate(asset: Asset, swap_tenor: str, rateoption_type: str
                             forward_tenor: Optional[GENERIC_DATE] = None,
                             clearing_house: tm_rates._ClearingHouse = None,
                             location: PricingLocation = None, *,
-                            source: str = None, real_time: bool = False) -> Series:
+                            source: str = None, real_time: bool = False) -> pd.Series:
     """
     GS end-of-day Zero Coupon CrossCurrency Swap curves across major currencies.
 
