@@ -14,11 +14,17 @@
 # Marquee Plot Service will attempt to make public functions (not prefixed with _) from this module available.
 # Such functions should be fully documented: docstrings should describe parameters and the return value, and provide
 # a 1-line description. Type annotations should be provided for parameters.
+from enum import Enum
+from typing import Union
+
 import pandas as pd
 import statsmodels.tsa.seasonal
 
 from gs_quant.timeseries import diff, annualize, returns
-from .statistics import *
+from .algebra import subtract
+from .helper import Window, plot_function, normalize_window, apply_ramp
+from .statistics import mean, std, exponential_std
+from ..errors import MqValueError
 
 """
 Technicals library is for technical analysis functions on timeseries, including moving averages,
@@ -102,9 +108,9 @@ def bollinger_bands(x: pd.Series, w: Union[Window, int, str] = Window(None, 0),
     a range around the price level which responds to local volatility changes. Returns two series,
     upper, :math:`u_t` and lower, :math:`l_t`
 
-    :math:`u_t = \\bar{X_t} + k\sigma_t`
+    :math:`u_t = \\bar{X_t} + k\\sigma_t`
 
-    :math:`l_t = \\bar{X_t} - k\sigma_t`
+    :math:`l_t = \\bar{X_t} - k\\sigma_t`
 
     where :math:`\\bar{X_t}` is the moving average over specified window, and :math:`\\sigma_t` is the rolling
     standard deviation over the specified window
@@ -174,19 +180,20 @@ def smoothed_moving_average(x: pd.Series, w: Union[Window, int, str] = Window(No
     means = apply_ramp(mean(x, Window(window_size, 0)), w)
     if means.size < 1:
         return pd.Series(dtype=float)
-    initial_moving_average = means[0]
+    initial_moving_average = means.iloc[0]
     if (isinstance(ramp, int) and ramp > 0) or isinstance(ramp, pd.DateOffset):
         x = apply_ramp(x, w)
 
     smoothed_moving_averages = x.copy()
     smoothed_moving_averages *= 0
-    smoothed_moving_averages[0] = initial_moving_average
+    smoothed_moving_averages.iloc[0] = initial_moving_average
     for i in range(1, len(x)):
         if isinstance(window_size, int):
             window_num_elem = window_size
         else:
-            window_num_elem = len(x[(x.index > (x.index[i] - window_size)) & (x.index <= x.index[i])])
-        smoothed_moving_averages[i] = ((window_num_elem - 1) * smoothed_moving_averages[i - 1] + x[i]) / window_num_elem
+            window_num_elem = len(x[(x.index > (x.index[i] - window_size).date()) & (x.index <= x.index[i])])
+        smoothed_moving_averages.iloc[i] = ((window_num_elem - 1) *
+                                            smoothed_moving_averages.iloc[i - 1] + x.iloc[i]) / window_num_elem
     return smoothed_moving_averages
 
 
@@ -235,11 +242,11 @@ def relative_strength_index(x: pd.Series, w: Union[Window, int, str] = 14) -> pd
     rsi *= 0
 
     for index in range(0, rsi_len):
-        if moving_avg_losses[index] == 0:
-            rsi[index] = 100
+        if moving_avg_losses.iloc[index] == 0:
+            rsi.iloc[index] = 100
         else:
-            relative_strength = moving_avg_gains[index] / moving_avg_losses[index]
-            rsi[index] = 100 - (100 / (1 + relative_strength))
+            relative_strength = moving_avg_gains.iloc[index] / moving_avg_losses.iloc[index]
+            rsi.iloc[index] = 100 - (100 / (1 + relative_strength))
 
     return rsi
 
@@ -308,7 +315,7 @@ def macd(x: pd.Series, m: int = 12, n: int = 26, s: int = 1) -> pd.Series:
 
     :math:`Y_0 = X_0`
 
-    :math:`Y_t = \\beta \cdot Y_{t-1} + (1 - \\beta) \cdot X_t`
+    :math:`Y_t = \\beta \\cdot Y_{t-1} + (1 - \\beta) \\cdot X_t`
 
     where :math:`\\beta = \\frac{2}{\\text{period} + 1}` is the weight we place on the previous average.
 
@@ -420,10 +427,10 @@ def _freq_to_period(x: pd.Series, freq: Frequency = Frequency.YEAR):
     if not isinstance(x.index, pd.DatetimeIndex):
         raise MqValueError("Series must have a pandas.DateTimeIndex.")
     pfreq = getattr(getattr(x, 'index', None), 'inferred_freq', None)
-    try:
-        period = statsmodels.tsa.seasonal.freq_to_period(pfreq)
-    except (ValueError, AttributeError):
-        period = None
+    # Some older versions of statsmodels don't handle some of the newer pandas frequencies, so we manually adjust them
+    pfreq = 'MS' if pfreq in ('ME', 'M') else pfreq  # Convert Month[End] into MonthlyStart
+    pfreq = 'QS' if pfreq in ('QE-DEC', 'QE') else pfreq  # Convert Quarter[End] into QuarterlyStart
+    period = None if pfreq is None else statsmodels.tsa.seasonal.freq_to_period(pfreq)
     if period in [7, None]:  # daily
         x = x.asfreq('D', method='ffill')
         if freq == Frequency.YEAR:
@@ -454,7 +461,7 @@ def _freq_to_period(x: pd.Series, freq: Frequency = Frequency.YEAR):
         else:
             raise MqValueError(f'Frequency {freq.value} not compatible with series with frequency {pfreq}.')
     elif period == 12:  # monthly frequency
-        x = x.asfreq('M', method='ffill')
+        x = x.asfreq('ME', method='ffill')
         if freq == Frequency.YEAR:
             return x, period
         elif freq == Frequency.QUARTER:
